unit IGC;

interface

uses
   Classes;

// To make Delphi 7.0 happy...
{$IFDEF VER150}
   {$WARN UNSAFE_CODE OFF}
{$ENDIF}

type TIGCsourceMessageRequestedEventInputsHandle = Pointer;
type TIGCsourceMessageRequestedEventInputsHandlePtr = ^TIGCsourceMessageRequestedEventInputsHandle;
type TIGCsourceMessageRequestedEventOutputsHandle = Pointer;
type TIGCsourceMessageRequestedEventOutputsHandlePtr = ^TIGCsourceMessageRequestedEventOutputsHandle;
type TIGCsourceMessageRequestCompletedEventInputsHandle = Pointer;
type TIGCsourceMessageRequestCompletedEventInputsHandlePtr = ^TIGCsourceMessageRequestCompletedEventInputsHandle;
type TIGCsourceMessageRequestCompletedEventOutputsHandle = Pointer;
type TIGCsourceMessageRequestCompletedEventOutputsHandlePtr = ^TIGCsourceMessageRequestCompletedEventOutputsHandle;
type TIGCdestinationMessageReceivedEventInputsHandle = Pointer;
type TIGCdestinationMessageReceivedEventInputsHandlePtr = ^TIGCdestinationMessageReceivedEventInputsHandle;
type TIGCdestinationMessageReceivedEventOutputsHandle = Pointer;
type TIGCdestinationMessageReceivedEventOutputsHandlePtr = ^TIGCdestinationMessageReceivedEventOutputsHandle;
type TIGCdisconnectReasonHandle = Pointer;
type TIGCdisconnectReasonHandlePtr = ^TIGCdisconnectReasonHandle;
type TIGCsourceHandle = Pointer;
type TIGCsourceHandlePtr = ^TIGCsourceHandle;
type TIGCdestinationHandle = Pointer;
type TIGCdestinationHandlePtr = ^TIGCdestinationHandle;
type TIGClogMessageHandle = Pointer;
type TIGClogMessageHandlePtr = ^TIGClogMessageHandle;
type TIGClogQueryResultHandle = Pointer;
type TIGClogQueryResultHandlePtr = ^TIGClogQueryResultHandle;
type TIGClogQueryHandle = Pointer;
type TIGClogQueryHandlePtr = ^TIGClogQueryHandle;


{: 
   This class is used to pass data from Iguana to OnMessageRequested event 
  handlers. 
  
   At present, no data is actually passed by Iguana to OnMessageRequested event 
  handlers. 
  
   This class is provided for future extensibility. 
  
}
type IIGCsourceMessageRequestedEventInputs = interface
   {$IFNDEF HIDE}
   {$ENDIF}
   end;
   


{: 
   This class is used to send response data from OnMessageRequested event handlers 
  back to Iguana. 
  
   Source plugins are provided with an instance of this class as an argument to 
  their OnMessageRequested event handler. The event handler uses the properties 
  and methods of the provided instance to craft a suitable response to send back 
  to Iguana. After the event handler returns, the response is sent back to Iguana.
   
  
   At a minimum, the event handler should set the OutboundMessage and 
  PluginMessageId properties to appropriate values. 
  
   The plugin event handler may request that the Iguana channel be stopped via the 
  StopChannelFlag, StopChannelErrorFlag and StopChannelReason properties. 
  
   The plugin event handler may add log messages to Iguana's logs using the 
  AddErrorLogMessage, AddWarningLogMessage, AddInfoLogMessage and 
  AddDebugLogMessage methods. 
  
}
type IIGCsourceMessageRequestedEventOutputs = interface
   {$IFNDEF HIDE}
   
   {: 
      Message to send back to Iguana, or an empty string if a message is not 
     presently available. 
     
     See also the SetOutboundMessage method.
     
   }
   function GetOutboundMessage : AnsiString;
   
   {: 
     Set method for OutboundMessage.
     
     See OutboundMessage.
     
   }
   procedure SetOutboundMessage(Value : AnsiString);
   
   {: 
      Id to be assigned by the plugin to uniquely identify OutboundMessage. 
     
      Iguana sends the provided PluginMessageId back to the plugin's 
     OnMessageRequestCompleted event handler via PluginMessageId property. This 
     allows the plugin to associate each message request completed notification with 
     the message sent to Iguana. 
     
      The format of the PluginMessageId is to be determined by the plugin author. 
     Iguana does not interpret this value, other than by adding it to logs, and 
     sending it back to the plugin. 
     
     See also the SetPluginMessageId method.
     
   }
   function GetPluginMessageId : AnsiString;
   
   {: 
     Set method for PluginMessageId.
     
     See PluginMessageId.
     
   }
   procedure SetPluginMessageId(Value : AnsiString);
   
   {: 
      Requests that Iguana stop the channel to which the plugin is connected. 
     
      Default value: false. 
     
      See also: StopChannelErrorFlag and StopChannelReason. 
     
     See also the SetStopChannelFlag method.
     
   }
   function GetStopChannelFlag : Boolean;
   
   {: 
     Set method for StopChannelFlag.
     
     See StopChannelFlag.
     
   }
   procedure SetStopChannelFlag(Value : Boolean);
   
   {: 
      When combined with StopChannelFlag, requests that Iguana stop the channel with 
     the channel status set to 'error'. 
     
      Default value: false. 
     
      Only applicable if StopChannelFlag is set to true. 
     
     See also the SetStopChannelErrorFlag method.
     
   }
   function GetStopChannelErrorFlag : Boolean;
   
   {: 
     Set method for StopChannelErrorFlag.
     
     See StopChannelErrorFlag.
     
   }
   procedure SetStopChannelErrorFlag(Value : Boolean);
   
   {: 
      Describes the reason for the 'stop channel' request. 
     
      Only applicable if StopChannelFlag is set to true. 
     
     See also the SetStopChannelReason method.
     
   }
   function GetStopChannelReason : AnsiString;
   
   {: 
     Set method for StopChannelReason.
     
     See StopChannelReason.
     
   }
   procedure SetStopChannelReason(Value : AnsiString);
   {$ENDIF}
   
   {: 
      Adds an error log message to Iguana's logs. 
     
   }
   procedure AddErrorLogMessage(ErrorLogMessage : AnsiString);
   
   {: 
      Adds a warning log message to Iguana's logs. 
     
   }
   procedure AddWarningLogMessage(WarningLogMessage : AnsiString);
   
   {: 
      Adds an info log message to Iguana's logs. 
     
   }
   procedure AddInfoLogMessage(InfoLogMessage : AnsiString);
   
   {: 
      Adds a debug log message to Iguana's logs. 
     
   }
   procedure AddDebugLogMessage(DebugLogMessage : AnsiString);
   
   {: 
      Message to send back to Iguana, or an empty string if a message is not 
     presently available. 
     
   }
   property OutboundMessage : AnsiString read GetOutboundMessage write SetOutboundMessage;
   
   
   {: 
      Id to be assigned by the plugin to uniquely identify OutboundMessage. 
     
      Iguana sends the provided PluginMessageId back to the plugin's 
     OnMessageRequestCompleted event handler via PluginMessageId property. This 
     allows the plugin to associate each message request completed notification with 
     the message sent to Iguana. 
     
      The format of the PluginMessageId is to be determined by the plugin author. 
     Iguana does not interpret this value, other than by adding it to logs, and 
     sending it back to the plugin. 
     
   }
   property PluginMessageId : AnsiString read GetPluginMessageId write SetPluginMessageId;
   
   
   {: 
      Requests that Iguana stop the channel to which the plugin is connected. 
     
      Default value: false. 
     
      See also: StopChannelErrorFlag and StopChannelReason. 
     
   }
   property StopChannelFlag : Boolean read GetStopChannelFlag write SetStopChannelFlag;
   
   
   {: 
      When combined with StopChannelFlag, requests that Iguana stop the channel with 
     the channel status set to 'error'. 
     
      Default value: false. 
     
      Only applicable if StopChannelFlag is set to true. 
     
   }
   property StopChannelErrorFlag : Boolean read GetStopChannelErrorFlag write SetStopChannelErrorFlag;
   
   
   {: 
      Describes the reason for the 'stop channel' request. 
     
      Only applicable if StopChannelFlag is set to true. 
     
   }
   property StopChannelReason : AnsiString read GetStopChannelReason write SetStopChannelReason;
   
   end;
   


{: 
   This class is used to pass data from Iguana to OnMessageRequestCompleted event 
  handlers. 
  
}
type IIGCsourceMessageRequestCompletedEventInputs = interface
   {$IFNDEF HIDE}
   
   {: 
      Id assigned by the plugin's OnMessageRequested event handler via the 
     PluginMessageId property. This allows the plugin to associate each message 
     request completed notification with the message sent to Iguana. 
     
      The format of the PluginMessageId is to be determined by the plugin author. 
     Iguana does not interpret this value, other than by adding it to logs, and 
     sending it back to the plugin. 
     
   }
   function GetPluginMessageId : AnsiString;
   
   {: 
      Id assigned by Iguana uniquely identifying the generated message within 
     Iguana's logs. 
     
      The Message Log Id may be used to query Iguana for additional message-related 
     information. 
     
      See 
     
      http://www.interfaceware.com/manual/iguana4_using_message_id.html 
     
   }
   function GetMessageLogId : AnsiString;
   
   {: 
      Flag indicating whether or not message was processed by Iguana. 
     
      If true, the message has been processed by Iguana and does not need to be 
     resent. The plugin should respond to the next OnMessageRequested event with the 
     next available message. 
     
      If false, the message has not been processed by Iguana and needs to be resent. 
     The plugin should respond to the next OnMessageRequested event with the same 
     message. 
     
   }
   function GetMessageProcessed : Boolean;
   {$ENDIF}
   
   {: 
      Id assigned by the plugin's OnMessageRequested event handler via the 
     PluginMessageId property. This allows the plugin to associate each message 
     request completed notification with the message sent to Iguana. 
     
      The format of the PluginMessageId is to be determined by the plugin author. 
     Iguana does not interpret this value, other than by adding it to logs, and 
     sending it back to the plugin. 
     
   }
   property PluginMessageId : AnsiString read GetPluginMessageId;
   
   
   {: 
      Id assigned by Iguana uniquely identifying the generated message within 
     Iguana's logs. 
     
      The Message Log Id may be used to query Iguana for additional message-related 
     information. 
     
      See 
     
      http://www.interfaceware.com/manual/iguana4_using_message_id.html 
     
   }
   property MessageLogId : AnsiString read GetMessageLogId;
   
   
   {: 
      Flag indicating whether or not message was processed by Iguana. 
     
      If true, the message has been processed by Iguana and does not need to be 
     resent. The plugin should respond to the next OnMessageRequested event with the 
     next available message. 
     
      If false, the message has not been processed by Iguana and needs to be resent. 
     The plugin should respond to the next OnMessageRequested event with the same 
     message. 
     
   }
   property MessageProcessed : Boolean read GetMessageProcessed;
   
   end;
   


{: 
   This class is used to send response data from OnMessageRequestCompleted event 
  handlers back to Iguana. 
  
   At present, no data is actually sent back to Iguana from 
  OnMessageRequestCompleted event handlers. 
  
   This class is provided for future extensibility. 
  
}
type IIGCsourceMessageRequestCompletedEventOutputs = interface
   {$IFNDEF HIDE}
   {$ENDIF}
   end;
   


{: 
   This class is used to pass data from Iguana to OnMessageReceived and 
  OnResubmissionPreviewMessageReceived event handlers. 
  
}
type IIGCdestinationMessageReceivedEventInputs = interface
   {$IFNDEF HIDE}
   
   {: 
      Message received from Iguana. 
     
   }
   function GetMessage : AnsiString;
   
   {: 
      Id assigned by Iguana uniquely identifying the received message within Iguana's 
     logs. 
     
      The Message Log Id may be used to query Iguana for additional message-related 
     information. 
     
      See 
     
      http://www.interfaceware.com/manual/iguana4_using_message_id.html 
     
      Note that Message Log Ids are not supplied to 
     OnResubmissionPreviewMessageReceived events, since Iguana does not assign 
     Message Log Ids to resubmission preview messages. 
     
   }
   function GetMessageLogId : AnsiString;
   {$ENDIF}
   
   {: 
      Message received from Iguana. 
     
   }
   property Message : AnsiString read GetMessage;
   
   
   {: 
      Id assigned by Iguana uniquely identifying the received message within Iguana's 
     logs. 
     
      The Message Log Id may be used to query Iguana for additional message-related 
     information. 
     
      See 
     
      http://www.interfaceware.com/manual/iguana4_using_message_id.html 
     
      Note that Message Log Ids are not supplied to 
     OnResubmissionPreviewMessageReceived events, since Iguana does not assign 
     Message Log Ids to resubmission preview messages. 
     
   }
   property MessageLogId : AnsiString read GetMessageLogId;
   
   end;
   


{: 
   This class is used to send response data from OnMessageReceived event handlers 
  back to Iguana. 
  
   Destination plugins are provided with an instance of this class as an argument 
  to their OnMessageReceived event handler. The event handler uses the properties 
  and methods of the provided instance to craft a suitable response to send back 
  to Iguana. After the event handler returns, the response is sent back to Iguana.
   
  
   At a minimum, the event handler should set the MessageProcessedFlag property to 
  true to indicate to Iguana that the message was received and processed by the 
  plugin. Setting this property to false will simply result in Iguana logging a 
  generic error message; it will not result in Iguana resending the message or 
  stopping the channel. Plugins can achieve more sophisticated and precise error 
  handling using the properties and methods described below. 
  
   If the event handler is unable to complete processing in a timely fashion, it 
  should use the ResendMessageFlag and ResendMessageDelay properties to request 
  that Iguana resend the message. This ensures that Iguana does not time-out the 
  connection to the plugin due to inactivity. The exact duration of the time-out 
  is determined by the Plugin Time field value configured for the To Plugin 
  channel component to which the plugin is connected. 
  
   The plugin event handler may request that the Iguana channel be stopped via the 
  StopChannelFlag, StopChannelErrorFlag and StopChannelReason properties. 
  
   The plugin event handler may add log messages to Iguana's logs using the 
  AddErrorLogMessage, AddWarningLogMessage, AddInfoLogMessage and 
  AddDebugLogMessage methods. 
  
}
type IIGCdestinationMessageReceivedEventOutputs = interface
   {$IFNDEF HIDE}
   
   {: 
      Indicates to Iguana whether or not the message was processed by the plugin. 
     
      Default value: false. 
     
      Should generally be set by event handlers to true. 
     
      If set to false, Iguana will simply issue a relatively generic error message. 
     Event handlers can add their own specific error log message to the Iguana logs 
     using the AddErrorLogMessage method instead. 
     
     See also the SetMessageProcessedFlag method.
     
   }
   function GetMessageProcessedFlag : Boolean;
   
   {: 
     Set method for MessageProcessedFlag.
     
     See MessageProcessedFlag.
     
   }
   procedure SetMessageProcessedFlag(Value : Boolean);
   
   {: 
      Requests that Iguana resend the message. 
     
      Default value: false. 
     
      The message will be resent after the delay specified by ResendMessageDelay. 
     
      If the channel is stopped, the message will be resent once the channel is 
     restarted. 
     
     See also the SetResendMessageFlag method.
     
   }
   function GetResendMessageFlag : Boolean;
   
   {: 
     Set method for ResendMessageFlag.
     
     See ResendMessageFlag.
     
   }
   procedure SetResendMessageFlag(Value : Boolean);
   
   {: 
      Specifies the delay time in milliseconds that Iguana should wait before 
     resending the message. 
     
      Default value: 0 milliseconds. 
     
      Only applicable if ResendMessageFlag is set to true. 
     
     See also the SetResendMessageDelay method.
     
   }
   function GetResendMessageDelay : Integer;
   
   {: 
     Set method for ResendMessageDelay.
     
     See ResendMessageDelay.
     
   }
   procedure SetResendMessageDelay(Value : Integer);
   
   {: 
      Requests that Iguana stop the channel to which the plugin is connected. 
     
      Default value: false. 
     
      See also: StopChannelErrorFlag and StopChannelReason. 
     
     See also the SetStopChannelFlag method.
     
   }
   function GetStopChannelFlag : Boolean;
   
   {: 
     Set method for StopChannelFlag.
     
     See StopChannelFlag.
     
   }
   procedure SetStopChannelFlag(Value : Boolean);
   
   {: 
      When combined with StopChannelFlag, requests that Iguana stop the channel with 
     the channel status set to 'error'. 
     
      Default value: false. 
     
      Only applicable if StopChannelFlag is set to true. 
     
     See also the SetStopChannelErrorFlag method.
     
   }
   function GetStopChannelErrorFlag : Boolean;
   
   {: 
     Set method for StopChannelErrorFlag.
     
     See StopChannelErrorFlag.
     
   }
   procedure SetStopChannelErrorFlag(Value : Boolean);
   
   {: 
      Describes the reason for the 'stop channel' request. 
     
      Only applicable if StopChannelFlag is set to true. 
     
     See also the SetStopChannelReason method.
     
   }
   function GetStopChannelReason : AnsiString;
   
   {: 
     Set method for StopChannelReason.
     
     See StopChannelReason.
     
   }
   procedure SetStopChannelReason(Value : AnsiString);
   {$ENDIF}
   
   {: 
      Adds an error log message to Iguana's logs. 
     
   }
   procedure AddErrorLogMessage(ErrorLogMessage : AnsiString);
   
   {: 
      Adds a warning log message to Iguana's logs. 
     
   }
   procedure AddWarningLogMessage(WarningLogMessage : AnsiString);
   
   {: 
      Adds an info log message to Iguana's logs. 
     
   }
   procedure AddInfoLogMessage(InfoLogMessage : AnsiString);
   
   {: 
      Adds a debug log message to Iguana's logs. 
     
   }
   procedure AddDebugLogMessage(DebugLogMessage : AnsiString);
   
   {: 
      Indicates to Iguana whether or not the message was processed by the plugin. 
     
      Default value: false. 
     
      Should generally be set by event handlers to true. 
     
      If set to false, Iguana will simply issue a relatively generic error message. 
     Event handlers can add their own specific error log message to the Iguana logs 
     using the AddErrorLogMessage method instead. 
     
   }
   property MessageProcessedFlag : Boolean read GetMessageProcessedFlag write SetMessageProcessedFlag;
   
   
   {: 
      Requests that Iguana resend the message. 
     
      Default value: false. 
     
      The message will be resent after the delay specified by ResendMessageDelay. 
     
      If the channel is stopped, the message will be resent once the channel is 
     restarted. 
     
   }
   property ResendMessageFlag : Boolean read GetResendMessageFlag write SetResendMessageFlag;
   
   
   {: 
      Specifies the delay time in milliseconds that Iguana should wait before 
     resending the message. 
     
      Default value: 0 milliseconds. 
     
      Only applicable if ResendMessageFlag is set to true. 
     
   }
   property ResendMessageDelay : Integer read GetResendMessageDelay write SetResendMessageDelay;
   
   
   {: 
      Requests that Iguana stop the channel to which the plugin is connected. 
     
      Default value: false. 
     
      See also: StopChannelErrorFlag and StopChannelReason. 
     
   }
   property StopChannelFlag : Boolean read GetStopChannelFlag write SetStopChannelFlag;
   
   
   {: 
      When combined with StopChannelFlag, requests that Iguana stop the channel with 
     the channel status set to 'error'. 
     
      Default value: false. 
     
      Only applicable if StopChannelFlag is set to true. 
     
   }
   property StopChannelErrorFlag : Boolean read GetStopChannelErrorFlag write SetStopChannelErrorFlag;
   
   
   {: 
      Describes the reason for the 'stop channel' request. 
     
      Only applicable if StopChannelFlag is set to true. 
     
   }
   property StopChannelReason : AnsiString read GetStopChannelReason write SetStopChannelReason;
   
   end;
   


{: 
   This class is used to describe the reason for a plugin's disconnection from 
  Iguana. 
  
   The IIGCdisconnectReason for a plugin's most recent disconnection from Iguana 
  may be retrieved from the DisconnectReason or DisconnectReason properties, 
  depending on the type of the plugin. 
  
   The disconnect reason includes three mutually exclusive flags indicating the 
  reason for the disconnection: DueToIguana, DueToPlugin, and DueToError. These 
  flags can be used programmatically to customize plugin disconnection handling 
  depending on the cause of the disconnection. 
  
   The disconnect reason includes a textual description of the reason for 
  disconnection: Description. The textual description may contain additional 
  details useful in diagnosing unexpected disconnections, especially in the case 
  of disconnection due to errors. 
  
}
type IIGCdisconnectReason = interface
   {$IFNDEF HIDE}
   
   {: 
      Indicates that Iguana closed the connection with the plugin. 
     
      Iguana closes its connection with a plugin when stopping the plugin channel. 
     
   }
   function GetDueToIguana : Boolean;
   
   {: 
      Indicates that the plugin requested disconnection from Iguana. 
     
      Plugins may request disconnection by invoking the Disconnect or Disconnect 
     methods, depending on the type of plugin. 
     
   }
   function GetDueToPlugin : Boolean;
   
   {: 
      Indicates that the connection between Iguana and the plugin was closed due to 
     an error. 
     
      A textual description of the error is available via the Description property. 
     
   }
   function GetDueToError : Boolean;
   
   {: 
      Provides a textual description of the reason for disconnection. 
     
   }
   function GetDescription : AnsiString;
   {$ENDIF}
   
   {: 
      Indicates that Iguana closed the connection with the plugin. 
     
      Iguana closes its connection with a plugin when stopping the plugin channel. 
     
   }
   property DueToIguana : Boolean read GetDueToIguana;
   
   
   {: 
      Indicates that the plugin requested disconnection from Iguana. 
     
      Plugins may request disconnection by invoking the Disconnect or Disconnect 
     methods, depending on the type of plugin. 
     
   }
   property DueToPlugin : Boolean read GetDueToPlugin;
   
   
   {: 
      Indicates that the connection between Iguana and the plugin was closed due to 
     an error. 
     
      A textual description of the error is available via the Description property. 
     
   }
   property DueToError : Boolean read GetDueToError;
   
   
   {: 
      Provides a textual description of the reason for disconnection. 
     
   }
   property Description : AnsiString read GetDescription;
   
   end;
   

{: 
   Event raised upon reciept of a message request from Iguana. 
  
   The plugin should respond with either the next available unacknowledged 
  message, or an empty message if no messages are available. 
  
   Exceptions should never be allowed to propagate out of the event handler. Event 
  handlers should catch and handle all exceptions internally. 
  
}
TIGCsourceMessageRequestedEvent =  procedure(Sender : TObject; Inputs : IIGCsourceMessageRequestedEventInputs; Outputs : IIGCsourceMessageRequestedEventOutputs) of Object;

{: 
   Event raised upon receipt of a message request completed notification from 
  Iguana. 
  
   Exceptions should never be allowed to propagate out of the event handler. Event 
  handlers should catch and handle all exceptions internally. 
  
}
TIGCsourceMessageRequestCompletedEvent =  procedure(Sender : TObject; Inputs : IIGCsourceMessageRequestCompletedEventInputs; Outputs : IIGCsourceMessageRequestCompletedEventOutputs) of Object;

{: 
   Event raised upon disconnection of the plugin from Iguana. 
  
   Will not be raised for failed connection attempts. Specifically, will not be 
  raised if Connect throws an exception as a result of a connection failure. 
  
   Exceptions should never be allowed to propagate out of the event handler. Event 
  handlers should catch and handle all exceptions internally. 
  
}
TIGCsourceDisconnectedEvent =  procedure(Sender : TObject) of Object;


{: 
   This class is used to implement an Iguana source plugin. 
  
   Source plugins connect to, and send messages to Iguana From-Plugin channel 
  components. 
  
   Messages are sent to Iguana using a "polling" or "pull" approach (as opposed to 
  a "push" approach). Iguana sends a message request to the TIGCsource plugin, 
  raising the OnMessageRequested event. The TIGCsource plugin responds with the 
  next available unacknowledged message. Once Iguana has received and enqueued the 
  message, a message request completed notification is sent back to the TIGCsource 
  plugin, raising the OnMessageRequestCompleted event. The TIGCsource plugin notes 
  that the message has been acknowledged, and that it can advance to the next 
  available message. 
  
   The message polling cycle repeats without delay while messages are available. 
  Once all available messages have been transferred (indicated by the plugin 
  responding to a message request with an empty message), the cycle repeats at an 
  interval determined by the Polling Time configured in the channel's From-Plugin 
  component. 
  
   See 
  
   http://www.interfaceware.com/manual/plugin_sending.html 
  
   for more information. 
  
}
type TIGCsource = class(TComponent)
   private
      {$IFNDEF HIDE}
      FHandle : TIGCsourceHandle;
      FOnMessageRequested : TIGCsourceMessageRequestedEvent;
      FOnMessageRequestCompleted : TIGCsourceMessageRequestCompletedEvent;
      FOnDisconnected : TIGCsourceDisconnectedEvent;
      
      {: 
         Describes the reason for the plugin's (most recent) disconnection from Iguana. 
        
         Only valid after the plugin has been disconnected, and before any subsequent 
        connection attempts. Specifically, only valid within the OnDisconnected handler 
        or after the return of a call to WaitForDisconnect or 
        WaitForDisconnectWithTimeout, and before any subsequent calls to Connect. 
        
      }
      function GetDisconnectReason : IIGCdisconnectReason;
      
      {: 
         Time in milliseconds the plugin will wait to handshake with Iguana while 
        executing the Connect operation (default 5000 milliseconds). 
        
         For a heavily loaded Iguana server running on a slow machine this may need a 
        higher value than the default value. 
        
        See also the SetConnectTimeout method.
        
      }
      function GetConnectTimeout : Integer;
      
      {: 
        Set method for ConnectTimeout.
        
        See ConnectTimeout.
        
      }
      procedure SetConnectTimeout(Value : Integer);
      {$ENDIF}
   public
      constructor Create(Owner : TComponent); override;
      destructor Destroy; override;
      
      {: 
         Enables logging of internal runtime debug information to the specified file. 
        
         Must be called before any other methods, and may only be called once per Source 
        instance. 
        
         This function should only be used at the request of iNTERFACEWARE Technical 
        Support. 
        
      }
      procedure EnableDebugLogging(FileName : AnsiString);
      
      {: 
         Connects to an Iguana From-Plugin channel component as a source plugin. 
        
         Should be called only while the plugin is disconnected (for example, after a 
        return from WaitForDisconnect). 
        
         May not be called from within an event handler (for example, may not be called 
        from within the OnDisconnected handler). 
        
         If a connection is not established within the timeout period specified by 
        ConnectTimeout, an exception will be thrown. The default timeout period of 5000 
        milliseconds should suffice for most plugins, and should only be adjusted if 
        connection timeouts are observed. 
        
         Throws: Function throws an exception upon connection failure or timeout, or if 
        called from within an event handler. 
        
      }
      procedure Connect(HostName : AnsiString; PortNumber : Integer; ChannelName : AnsiString);
      
      {: 
         Disconnects the plugin from Iguana. 
        
         Results in DisconnectReason being set to DueToPlugin. 
        
      }
      procedure Disconnect;
      
      {: 
         Waits until the plugin is disconnected from Iguana. 
        
         May not be called from within an event handler (for example, may not be called 
        from within the OnDisconnected handler). 
        
      }
      procedure WaitForDisconnect;
      
      {: 
         Waits until either the plugin is disconnected from Iguana, or a specified 
        timeout elapses. 
        
         May not be called from within an event handler (for example, may not be called 
        from within the OnDisconnected handler). 
        
      }
      function WaitForDisconnectWithTimeout(TimeoutInMilliseconds : Integer) : Boolean;
      
      {: 
         Describes the reason for the plugin's (most recent) disconnection from Iguana. 
        
         Only valid after the plugin has been disconnected, and before any subsequent 
        connection attempts. Specifically, only valid within the OnDisconnected handler 
        or after the return of a call to WaitForDisconnect or 
        WaitForDisconnectWithTimeout, and before any subsequent calls to Connect. 
        
      }
      property DisconnectReason : IIGCdisconnectReason read GetDisconnectReason;
      
      
      {: 
         Time in milliseconds the plugin will wait to handshake with Iguana while 
        executing the Connect operation (default 5000 milliseconds). 
        
         For a heavily loaded Iguana server running on a slow machine this may need a 
        higher value than the default value. 
        
      }
      property ConnectTimeout : Integer read GetConnectTimeout write SetConnectTimeout;
      
   published
      {: 
         Event raised upon reciept of a message request from Iguana. 
        
         The plugin should respond with either the next available unacknowledged 
        message, or an empty message if no messages are available. 
        
         Exceptions should never be allowed to propagate out of the event handler. Event 
        handlers should catch and handle all exceptions internally. 
        
      }
      property OnMessageRequested : TIGCsourceMessageRequestedEvent read FOnMessageRequested write FOnMessageRequested;
      
      {: 
         Event raised upon receipt of a message request completed notification from 
        Iguana. 
        
         Exceptions should never be allowed to propagate out of the event handler. Event 
        handlers should catch and handle all exceptions internally. 
        
      }
      property OnMessageRequestCompleted : TIGCsourceMessageRequestCompletedEvent read FOnMessageRequestCompleted write FOnMessageRequestCompleted;
      
      {: 
         Event raised upon disconnection of the plugin from Iguana. 
        
         Will not be raised for failed connection attempts. Specifically, will not be 
        raised if Connect throws an exception as a result of a connection failure. 
        
         Exceptions should never be allowed to propagate out of the event handler. Event 
        handlers should catch and handle all exceptions internally. 
        
      }
      property OnDisconnected : TIGCsourceDisconnectedEvent read FOnDisconnected write FOnDisconnected;
      
   end;
   

{: 
   Event raised upon receipt of a message from Iguana. 
  
   Exceptions should never be allowed to propagate out of the event handler. Event 
  handlers should catch and handle all exceptions internally. 
  
}
TIGCdestinationMessageReceivedEvent =  procedure(Sender : TObject; Inputs : IIGCdestinationMessageReceivedEventInputs; Outputs : IIGCdestinationMessageReceivedEventOutputs) of Object;

{: 
   Event raised upon receipt of a resubmission preview message from Iguana. 
  
   Plugins should simulate the processing that would be performed by the 
  OnMessageReceived event handler without causing external side effects. For 
  example, database changes should not be made for resubmission preview messages. 
  
   Exceptions should never be allowed to propagate out of the event handler. Event 
  handlers should catch and handle all exceptions internally. 
  
}
TIGCdestinationResubmissionPreviewMessageReceivedEvent =  procedure(Sender : TObject; Inputs : IIGCdestinationMessageReceivedEventInputs; Outputs : IIGCdestinationMessageReceivedEventOutputs) of Object;

{: 
   Event raised upon disconnection of the plugin from Iguana. 
  
   Will not be raised for failed connection attempts. Specifically, will not be 
  raised if Connect throws an exception as a result of a connection failure. 
  
   Exceptions should never be allowed to propagate out of the event handler. Event 
  handlers should catch and handle all exceptions internally. 
  
}
TIGCdestinationDisconnectedEvent =  procedure(Sender : TObject) of Object;


{: 
   This class is used to implement an Iguana destination plugin. 
  
   Destination plugins connect to, and receive messages from Iguana To-Plugin 
  channel components. 
  
   Messages are sent from Iguana to the TIGCdestination plugin through the 
  OnMessageReceived event. The plugin must set properties on the 
  IIGCdestinationMessageReceivedEventOutputs object passed to event handler to 
  communicate the results of message processing back to Iguana. 
  
   See: 
  
   http://www.interfaceware.com/manual/plugin_receiving.html 
  
   for more information. 
  
}
type TIGCdestination = class(TComponent)
   private
      {$IFNDEF HIDE}
      FHandle : TIGCdestinationHandle;
      FOnMessageReceived : TIGCdestinationMessageReceivedEvent;
      FOnResubmissionPreviewMessageReceived : TIGCdestinationResubmissionPreviewMessageReceivedEvent;
      FOnDisconnected : TIGCdestinationDisconnectedEvent;
      
      {: 
         Describes the reason for the plugin's (most recent) disconnection from Iguana. 
        
         Only valid after the plugin has been disconnected, and before any subsequent 
        connection attempts. Specifically, only valid within the OnDisconnected handler 
        or after the return of a call to WaitForDisconnect or 
        WaitForDisconnectWithTimeout, and before any subsequent calls to Connect. 
        
      }
      function GetDisconnectReason : IIGCdisconnectReason;
      
      {: 
         Time in milliseconds the plugin will wait to handshake with Iguana while 
        executing the Connect operation (default 5000 milliseconds). 
        
         For a heavily loaded Iguana server running on a slow machine this may need a 
        higher value than the default value. 
        
        See also the SetConnectTimeout method.
        
      }
      function GetConnectTimeout : Integer;
      
      {: 
        Set method for ConnectTimeout.
        
        See ConnectTimeout.
        
      }
      procedure SetConnectTimeout(Value : Integer);
      {$ENDIF}
   public
      constructor Create(Owner : TComponent); override;
      destructor Destroy; override;
      
      {: 
         Enables logging of internal runtime debug information to the specified file. 
        
         Must be called before any other methods, and may only be called once per 
        Destination instance. 
        
         This function should only be used at the request of iNTERFACEWARE Technical 
        Support. 
        
      }
      procedure EnableDebugLogging(FileName : AnsiString);
      
      {: 
         Connects to an Iguana To-Plugin channel component as a destination plugin. 
        
         Normally this method is called as the plugin starts and is ready to receive 
        data from Iguana or if Iguana has disconnected from the plugin such as after 
        returning from WaitForDisconnect). 
        
         It may not be called from within an event handler (for example, may not be 
        called from within the OnDisconnected handler). 
        
         If a connection is not established within the timeout period specified by 
        ConnectTimeout, an exception will be thrown. The default timeout period of 5000 
        milliseconds should suffice for most plugins, and should only be adjusted if 
        connection timeouts are observed. 
        
         One common point of confusion with users is the choice of port number for this 
        call. This must be for the Plugin Communication Server which is typically 6123 
        rather than say the LLP port for the particular plugin channel. 
        
         Throws: Function throws an exception upon connection failure or timeout, or if 
        called from within an event handler. 
        
      }
      procedure Connect(HostName : AnsiString; PortNumber : Integer; ChannelName : AnsiString);
      
      {: 
         Disconnects the plugin from Iguana. 
        
         Results in DisconnectReason being set to DueToPlugin. 
        
      }
      procedure Disconnect;
      
      {: 
         Waits until the plugin is disconnected from Iguana. 
        
         May not be called from within an event handler (for example, may not be called 
        from within the OnDisconnected handler). 
        
      }
      procedure WaitForDisconnect;
      
      {: 
         Waits until either the plugin is disconnected from Iguana, or a specified 
        timeout elapses. 
        
         May not be called from within an event handler (for example, may not be called 
        from within the OnDisconnected handler). 
        
      }
      function WaitForDisconnectWithTimeout(TimeoutInMilliseconds : Integer) : Boolean;
      
      {: 
         Describes the reason for the plugin's (most recent) disconnection from Iguana. 
        
         Only valid after the plugin has been disconnected, and before any subsequent 
        connection attempts. Specifically, only valid within the OnDisconnected handler 
        or after the return of a call to WaitForDisconnect or 
        WaitForDisconnectWithTimeout, and before any subsequent calls to Connect. 
        
      }
      property DisconnectReason : IIGCdisconnectReason read GetDisconnectReason;
      
      
      {: 
         Time in milliseconds the plugin will wait to handshake with Iguana while 
        executing the Connect operation (default 5000 milliseconds). 
        
         For a heavily loaded Iguana server running on a slow machine this may need a 
        higher value than the default value. 
        
      }
      property ConnectTimeout : Integer read GetConnectTimeout write SetConnectTimeout;
      
   published
      {: 
         Event raised upon receipt of a message from Iguana. 
        
         Exceptions should never be allowed to propagate out of the event handler. Event 
        handlers should catch and handle all exceptions internally. 
        
      }
      property OnMessageReceived : TIGCdestinationMessageReceivedEvent read FOnMessageReceived write FOnMessageReceived;
      
      {: 
         Event raised upon receipt of a resubmission preview message from Iguana. 
        
         Plugins should simulate the processing that would be performed by the 
        OnMessageReceived event handler without causing external side effects. For 
        example, database changes should not be made for resubmission preview messages. 
        
         Exceptions should never be allowed to propagate out of the event handler. Event 
        handlers should catch and handle all exceptions internally. 
        
      }
      property OnResubmissionPreviewMessageReceived : TIGCdestinationResubmissionPreviewMessageReceivedEvent read FOnResubmissionPreviewMessageReceived write FOnResubmissionPreviewMessageReceived;
      
      {: 
         Event raised upon disconnection of the plugin from Iguana. 
        
         Will not be raised for failed connection attempts. Specifically, will not be 
        raised if Connect throws an exception as a result of a connection failure. 
        
         Exceptions should never be allowed to propagate out of the event handler. Event 
        handlers should catch and handle all exceptions internally. 
        
      }
      property OnDisconnected : TIGCdestinationDisconnectedEvent read FOnDisconnected write FOnDisconnected;
      
   end;
   


{: 
   This class is used to represent an individual Iguana log message. 
  
}
type IIGClogMessage = interface
   {$IFNDEF HIDE}
   
   {: 
      Provides the name of the source channel associated with the message, or an 
     empty string if the message is not associated with a specific channel. 
     
   }
   function GetChannelName : AnsiString;
   
   {: 
      Provides the type of this message 
     (Message/Ack/Success/Warning/Error/Info/Debug) 
     
   }
   function GetMessageType : AnsiString;
   
   {: 
      Provides the full body of the message. 
     
   }
   function GetContent : AnsiString;
   
   {: 
      Provides the ID that is used to uniquely identify this message. This ID can be 
     used to query related messages. 
     
   }
   function GetMessageLogId : AnsiString;
   
   {: 
      Provides the ID of the parent of this message. It will be empty if there is no 
     parent. 
     
   }
   function GetReferenceLogId : AnsiString;
   
   {: 
      Provides a timestamp of the message with second precision. Milliseconds are 
     available via the Milliseconds property. 
     
   }
   function GetTimeStamp : TDateTime;
   
   {: 
      Provides the number of milliseconds (0-999) associated with the TimeStamp 
     property. 
     
   }
   function GetMilliseconds : Integer;
   
   {: 
      This flag is set if the message has been deleted through Iguana dashboard by an 
     administrator. 
     
   }
   function GetDeleted : Boolean;
   
   {: 
      This flag is set if this error has been marked (acknowledged) through Iguana 
     dashboard by an administrator. (Only applicable to message type Error) 
     
   }
   function GetMarkedError : Boolean;
   
   {: 
      This flag is set if this message is the original of a separate resubmitted 
     message. (Only applicable to message Type Message) 
     
   }
   function GetResubmitted : Boolean;
   
   {: 
      This flag is set if this message is a re-submission an earlier message. (Only 
     applicable to message Type Message) 
     
   }
   function GetIsResubmission : Boolean;
   {$ENDIF}
   
   {: 
      Provides the name of the source channel associated with the message, or an 
     empty string if the message is not associated with a specific channel. 
     
   }
   property ChannelName : AnsiString read GetChannelName;
   
   
   {: 
      Provides the type of this message 
     (Message/Ack/Success/Warning/Error/Info/Debug) 
     
   }
   property MessageType : AnsiString read GetMessageType;
   
   
   {: 
      Provides the full body of the message. 
     
   }
   property Content : AnsiString read GetContent;
   
   
   {: 
      Provides the ID that is used to uniquely identify this message. This ID can be 
     used to query related messages. 
     
   }
   property MessageLogId : AnsiString read GetMessageLogId;
   
   
   {: 
      Provides the ID of the parent of this message. It will be empty if there is no 
     parent. 
     
   }
   property ReferenceLogId : AnsiString read GetReferenceLogId;
   
   
   {: 
      Provides a timestamp of the message with second precision. Milliseconds are 
     available via the Milliseconds property. 
     
   }
   property TimeStamp : TDateTime read GetTimeStamp;
   
   
   {: 
      Provides the number of milliseconds (0-999) associated with the TimeStamp 
     property. 
     
   }
   property Milliseconds : Integer read GetMilliseconds;
   
   
   {: 
      This flag is set if the message has been deleted through Iguana dashboard by an 
     administrator. 
     
   }
   property Deleted : Boolean read GetDeleted;
   
   
   {: 
      This flag is set if this error has been marked (acknowledged) through Iguana 
     dashboard by an administrator. (Only applicable to message type Error) 
     
   }
   property MarkedError : Boolean read GetMarkedError;
   
   
   {: 
      This flag is set if this message is the original of a separate resubmitted 
     message. (Only applicable to message Type Message) 
     
   }
   property Resubmitted : Boolean read GetResubmitted;
   
   
   {: 
      This flag is set if this message is a re-submission an earlier message. (Only 
     applicable to message Type Message) 
     
   }
   property IsResubmission : Boolean read GetIsResubmission;
   
   end;
   


{: 
   This class is used to describe the result of Execute. 
  
}
type IIGClogQueryResult = interface
   {$IFNDEF HIDE}
   
   {: 
      Indicates that the query was executed successfully. 
     
   }
   function GetSuccess : Boolean;
   
   {: 
      Provides a textual description of the error which occured if Success is false. 
     
   }
   function GetErrorDescription : AnsiString;
   
   {: 
      Provides an array of IIGClogMessage which were returned by Iguana in response 
     to the query. 
     
   }
   function GetMessage(MessageIndex : Integer) : IIGClogMessage;
   {$ENDIF}
   
   {: 
     Returns the total number of Messages.
     
     See also the Message property.
     
   }
   function CountOfMessage : Integer;
   
   {: 
      Indicates that the query was executed successfully. 
     
   }
   property Success : Boolean read GetSuccess;
   
   
   {: 
      Provides a textual description of the error which occured if Success is false. 
     
   }
   property ErrorDescription : AnsiString read GetErrorDescription;
   
   
   {: 
      Provides an array of IIGClogMessage which were returned by Iguana in response 
     to the query. 
     
   }
   property Message[Index : Integer] : IIGClogMessage read GetMessage;
   
   end;
   


{: 
   This class is used to represent an Iguana log query. 
  
}
type TIGClogQuery = class(TComponent)
   private
      {$IFNDEF HIDE}
      FHandle : TIGClogQueryHandle;
      
      {: 
         Specifies the hostname or IP address of the Iguana server. 
        
        See also the SetHost method.
        
      }
      function GetHost : AnsiString;
      
      {: 
        Set method for Host.
        
        See Host.
        
      }
      procedure SetHost(Value : AnsiString);
      
      {: 
         Specifies the port number which is used to access the Iguana server's 
        HTTP/HTTPS interface. 
        
        See also the SetPort method.
        
      }
      function GetPort : Integer;
      
      {: 
        Set method for Port.
        
        See Port.
        
      }
      procedure SetPort(Value : Integer);
      
      {: 
         Specifies the username which should be used to authenticate with the Iguana 
        server. 
        
        See also the SetUsername method.
        
      }
      function GetUsername : AnsiString;
      
      {: 
        Set method for Username.
        
        See Username.
        
      }
      procedure SetUsername(Value : AnsiString);
      
      {: 
         Specifies the password which should be used to authenticate with the Iguana 
        server. 
        
        See also the SetPassword method.
        
      }
      function GetPassword : AnsiString;
      
      {: 
        Set method for Password.
        
        See Password.
        
      }
      procedure SetPassword(Value : AnsiString);
      
      {: 
         Specifies that Iguana server is configured to use HTTPS mode. 
        
        See also the SetEncrypt method.
        
      }
      function GetEncrypt : Boolean;
      
      {: 
        Set method for Encrypt.
        
        See Encrypt.
        
      }
      procedure SetEncrypt(Value : Boolean);
      
      {: 
         Restricts search results to log entries that contain specified text pattern in 
        the message contents. (Optional) 
        
        See also the SetFilter method.
        
      }
      function GetFilter : AnsiString;
      
      {: 
        Set method for Filter.
        
        See Filter.
        
      }
      procedure SetFilter(Value : AnsiString);
      
      {: 
         Restricts search results to specified channel. (Optional) 
        
        See also the SetChannelName method.
        
      }
      function GetChannelName : AnsiString;
      
      {: 
        Set method for ChannelName.
        
        See ChannelName.
        
      }
      procedure SetChannelName(Value : AnsiString);
      
      {: 
         If this field is set, the message with specified Message Id as well as messages 
        related to it are returned. When this field is set, the other search constraints 
        (Filter, ChannelName, IncludeMessageMessages, IncludeAckMessages, etc) are 
        ignored. 
        
        See also the SetMessageLogId method.
        
      }
      function GetMessageLogId : AnsiString;
      
      {: 
        Set method for MessageLogId.
        
        See MessageLogId.
        
      }
      procedure SetMessageLogId(Value : AnsiString);
      
      {: 
         Include log entries of Type "Message" (HL7 data message) in the query results. 
        
        See also the SetIncludeMessageMessages method.
        
      }
      function GetIncludeMessageMessages : Boolean;
      
      {: 
        Set method for IncludeMessageMessages.
        
        See IncludeMessageMessages.
        
      }
      procedure SetIncludeMessageMessages(Value : Boolean);
      
      {: 
         Include log entries of Type "Ack" (HL7 acknowledgement) in the query results. 
        
        See also the SetIncludeAckMessages method.
        
      }
      function GetIncludeAckMessages : Boolean;
      
      {: 
        Set method for IncludeAckMessages.
        
        See IncludeAckMessages.
        
      }
      procedure SetIncludeAckMessages(Value : Boolean);
      
      {: 
         Include log entries of Type "Success" (success events) in the query results. 
        
        See also the SetIncludeSuccessMessages method.
        
      }
      function GetIncludeSuccessMessages : Boolean;
      
      {: 
        Set method for IncludeSuccessMessages.
        
        See IncludeSuccessMessages.
        
      }
      procedure SetIncludeSuccessMessages(Value : Boolean);
      
      {: 
         Include log entries of Type "Warning" (warning events) in the query results. 
        
        See also the SetIncludeWarningMessages method.
        
      }
      function GetIncludeWarningMessages : Boolean;
      
      {: 
        Set method for IncludeWarningMessages.
        
        See IncludeWarningMessages.
        
      }
      procedure SetIncludeWarningMessages(Value : Boolean);
      
      {: 
         Include log entries of Type "Error" (both marked and unmarked) in the query 
        results. 
        
        See also the SetIncludeErrorMessages method.
        
      }
      function GetIncludeErrorMessages : Boolean;
      
      {: 
        Set method for IncludeErrorMessages.
        
        See IncludeErrorMessages.
        
      }
      procedure SetIncludeErrorMessages(Value : Boolean);
      
      {: 
         Include log entries of Type "Error" that are marked in the query results. An 
        error can be marked (acknowledged) through Iguana dashboard by an administrator.
         
        
        See also the SetIncludeMarkedErrorMessages method.
        
      }
      function GetIncludeMarkedErrorMessages : Boolean;
      
      {: 
        Set method for IncludeMarkedErrorMessages.
        
        See IncludeMarkedErrorMessages.
        
      }
      procedure SetIncludeMarkedErrorMessages(Value : Boolean);
      
      {: 
         Include log entries of Type "Error" that are not marked in the query results. 
        
        See also the SetIncludeUnmarkedErrorMessages method.
        
      }
      function GetIncludeUnmarkedErrorMessages : Boolean;
      
      {: 
        Set method for IncludeUnmarkedErrorMessages.
        
        See IncludeUnmarkedErrorMessages.
        
      }
      procedure SetIncludeUnmarkedErrorMessages(Value : Boolean);
      
      {: 
         Include log entries of Type "Info" (info events) in the query results. 
        
        See also the SetIncludeInfoMessages method.
        
      }
      function GetIncludeInfoMessages : Boolean;
      
      {: 
        Set method for IncludeInfoMessages.
        
        See IncludeInfoMessages.
        
      }
      procedure SetIncludeInfoMessages(Value : Boolean);
      
      {: 
         Include log entries of Type "Debug" (debug events) in the query results. 
        
        See also the SetIncludeDebugMessages method.
        
      }
      function GetIncludeDebugMessages : Boolean;
      
      {: 
        Set method for IncludeDebugMessages.
        
        See IncludeDebugMessages.
        
      }
      procedure SetIncludeDebugMessages(Value : Boolean);
      
      {: 
         Include log entries that are deleted in the query results. A log message can be 
        deleted through Iguana dashboard by an administrator. 
        
        See also the SetIncludeDeleted method.
        
      }
      function GetIncludeDeleted : Boolean;
      
      {: 
        Set method for IncludeDeleted.
        
        See IncludeDeleted.
        
      }
      procedure SetIncludeDeleted(Value : Boolean);
      
      {: 
         Include log entries that are not deleted in the query results. 
        
        See also the SetIncludeNonDeleted method.
        
      }
      function GetIncludeNonDeleted : Boolean;
      
      {: 
        Set method for IncludeNonDeleted.
        
        See IncludeNonDeleted.
        
      }
      procedure SetIncludeNonDeleted(Value : Boolean);
      
      {: 
         Indicates that messages associated with the source channel should be included. 
        
        See also the SetIncludeSourceLogs method.
        
      }
      function GetIncludeSourceLogs : Boolean;
      
      {: 
        Set method for IncludeSourceLogs.
        
        See IncludeSourceLogs.
        
      }
      procedure SetIncludeSourceLogs(Value : Boolean);
      
      {: 
         Specifies the starting timestamp for the search. (Optional) 
        
        See also the SetAfter method.
        
      }
      function GetAfter : TDateTime;
      
      {: 
        Set method for After.
        
        See After.
        
      }
      procedure SetAfter(Value : TDateTime);
      
      {: 
         Specifies the ending timestamp for the search. (Optional) 
        
        See also the SetBefore method.
        
      }
      function GetBefore : TDateTime;
      
      {: 
        Set method for Before.
        
        See Before.
        
      }
      procedure SetBefore(Value : TDateTime);
      {$ENDIF}
   public
      constructor Create(Owner : TComponent); override;
      destructor Destroy; override;
      
      {: 
         Perform a query on the configured Iguana server. Note that this method will 
        block while the query is performed. 
        
      }
      function Execute : IIGClogQueryResult;
      
      {: 
         Specifies the hostname or IP address of the Iguana server. 
        
      }
      property Host : AnsiString read GetHost write SetHost;
      
      
      {: 
         Specifies the port number which is used to access the Iguana server's 
        HTTP/HTTPS interface. 
        
      }
      property Port : Integer read GetPort write SetPort;
      
      
      {: 
         Specifies the username which should be used to authenticate with the Iguana 
        server. 
        
      }
      property Username : AnsiString read GetUsername write SetUsername;
      
      
      {: 
         Specifies the password which should be used to authenticate with the Iguana 
        server. 
        
      }
      property Password : AnsiString read GetPassword write SetPassword;
      
      
      {: 
         Specifies that Iguana server is configured to use HTTPS mode. 
        
      }
      property Encrypt : Boolean read GetEncrypt write SetEncrypt;
      
      
      {: 
         Restricts search results to log entries that contain specified text pattern in 
        the message contents. (Optional) 
        
      }
      property Filter : AnsiString read GetFilter write SetFilter;
      
      
      {: 
         Restricts search results to specified channel. (Optional) 
        
      }
      property ChannelName : AnsiString read GetChannelName write SetChannelName;
      
      
      {: 
         If this field is set, the message with specified Message Id as well as messages 
        related to it are returned. When this field is set, the other search constraints 
        (Filter, ChannelName, IncludeMessageMessages, IncludeAckMessages, etc) are 
        ignored. 
        
      }
      property MessageLogId : AnsiString read GetMessageLogId write SetMessageLogId;
      
      
      {: 
         Include log entries of Type "Message" (HL7 data message) in the query results. 
        
      }
      property IncludeMessageMessages : Boolean read GetIncludeMessageMessages write SetIncludeMessageMessages;
      
      
      {: 
         Include log entries of Type "Ack" (HL7 acknowledgement) in the query results. 
        
      }
      property IncludeAckMessages : Boolean read GetIncludeAckMessages write SetIncludeAckMessages;
      
      
      {: 
         Include log entries of Type "Success" (success events) in the query results. 
        
      }
      property IncludeSuccessMessages : Boolean read GetIncludeSuccessMessages write SetIncludeSuccessMessages;
      
      
      {: 
         Include log entries of Type "Warning" (warning events) in the query results. 
        
      }
      property IncludeWarningMessages : Boolean read GetIncludeWarningMessages write SetIncludeWarningMessages;
      
      
      {: 
         Include log entries of Type "Error" (both marked and unmarked) in the query 
        results. 
        
      }
      property IncludeErrorMessages : Boolean read GetIncludeErrorMessages write SetIncludeErrorMessages;
      
      
      {: 
         Include log entries of Type "Error" that are marked in the query results. An 
        error can be marked (acknowledged) through Iguana dashboard by an administrator.
         
        
      }
      property IncludeMarkedErrorMessages : Boolean read GetIncludeMarkedErrorMessages write SetIncludeMarkedErrorMessages;
      
      
      {: 
         Include log entries of Type "Error" that are not marked in the query results. 
        
      }
      property IncludeUnmarkedErrorMessages : Boolean read GetIncludeUnmarkedErrorMessages write SetIncludeUnmarkedErrorMessages;
      
      
      {: 
         Include log entries of Type "Info" (info events) in the query results. 
        
      }
      property IncludeInfoMessages : Boolean read GetIncludeInfoMessages write SetIncludeInfoMessages;
      
      
      {: 
         Include log entries of Type "Debug" (debug events) in the query results. 
        
      }
      property IncludeDebugMessages : Boolean read GetIncludeDebugMessages write SetIncludeDebugMessages;
      
      
      {: 
         Include log entries that are deleted in the query results. A log message can be 
        deleted through Iguana dashboard by an administrator. 
        
      }
      property IncludeDeleted : Boolean read GetIncludeDeleted write SetIncludeDeleted;
      
      
      {: 
         Include log entries that are not deleted in the query results. 
        
      }
      property IncludeNonDeleted : Boolean read GetIncludeNonDeleted write SetIncludeNonDeleted;
      
      
      {: 
         Indicates that messages associated with the source channel should be included. 
        
      }
      property IncludeSourceLogs : Boolean read GetIncludeSourceLogs write SetIncludeSourceLogs;
      
      
      {: 
         Specifies the starting timestamp for the search. (Optional) 
        
      }
      property After : TDateTime read GetAfter write SetAfter;
      
      
      {: 
         Specifies the ending timestamp for the search. (Optional) 
        
      }
      property Before : TDateTime read GetBefore write SetBefore;
      
   end;
   

function IGCsourceMessageRequestedEventInputsCreateObject : IIGCsourceMessageRequestedEventInputs;
function IGCsourceMessageRequestedEventInputsCreateObjectWithHandle(Handle : TIGCsourceMessageRequestedEventInputsHandle) : IIGCsourceMessageRequestedEventInputs;
function IGCsourceMessageRequestedEventOutputsCreateObject : IIGCsourceMessageRequestedEventOutputs;
function IGCsourceMessageRequestedEventOutputsCreateObjectWithHandle(Handle : TIGCsourceMessageRequestedEventOutputsHandle) : IIGCsourceMessageRequestedEventOutputs;
function IGCsourceMessageRequestCompletedEventInputsCreateObject : IIGCsourceMessageRequestCompletedEventInputs;
function IGCsourceMessageRequestCompletedEventInputsCreateObjectWithHandle(Handle : TIGCsourceMessageRequestCompletedEventInputsHandle) : IIGCsourceMessageRequestCompletedEventInputs;
function IGCsourceMessageRequestCompletedEventOutputsCreateObject : IIGCsourceMessageRequestCompletedEventOutputs;
function IGCsourceMessageRequestCompletedEventOutputsCreateObjectWithHandle(Handle : TIGCsourceMessageRequestCompletedEventOutputsHandle) : IIGCsourceMessageRequestCompletedEventOutputs;
function IGCdestinationMessageReceivedEventInputsCreateObject : IIGCdestinationMessageReceivedEventInputs;
function IGCdestinationMessageReceivedEventInputsCreateObjectWithHandle(Handle : TIGCdestinationMessageReceivedEventInputsHandle) : IIGCdestinationMessageReceivedEventInputs;
function IGCdestinationMessageReceivedEventOutputsCreateObject : IIGCdestinationMessageReceivedEventOutputs;
function IGCdestinationMessageReceivedEventOutputsCreateObjectWithHandle(Handle : TIGCdestinationMessageReceivedEventOutputsHandle) : IIGCdestinationMessageReceivedEventOutputs;
function IGCdisconnectReasonCreateObject : IIGCdisconnectReason;
function IGCdisconnectReasonCreateObjectWithHandle(Handle : TIGCdisconnectReasonHandle) : IIGCdisconnectReason;
function IGClogMessageCreateObject : IIGClogMessage;
function IGClogMessageCreateObjectWithHandle(Handle : TIGClogMessageHandle) : IIGClogMessage;
function IGClogQueryResultCreateObject : IIGClogQueryResult;
function IGClogQueryResultCreateObjectWithHandle(Handle : TIGClogQueryResultHandle) : IIGClogQueryResult;

{$IFNDEF HIDE}
procedure Register;
{$ENDIF}

implementation

uses IGCinterface;

procedure Register;
begin
   RegisterComponents('Chameleon', [TIGCsource, TIGCdestination, TIGClogQuery]);
end;

{: 
   This class is used to pass data from Iguana to OnMessageRequested event 
  handlers. 
  
   At present, no data is actually passed by Iguana to OnMessageRequested event 
  handlers. 
  
   This class is provided for future extensibility. 
  
}
type TIGCsourceMessageRequestedEventInputs = class(TIGCiunknown, IIGCsourceMessageRequestedEventInputs)
   private
      FHandle : TIGCsourceMessageRequestedEventInputsHandle;
   public
      constructor Create;
      constructor CreateWithHandle(Handle : TIGCsourceMessageRequestedEventInputsHandle);
      function _AddRef : Integer; override; stdcall;
      function _Release : Integer; override; stdcall;
      destructor Destroy; override;
      {$IFNDEF HIDE}
      {$ENDIF}
   end;
   
function IGCsourceMessageRequestedEventInputsCreate
(
   ReturnValue : TIGCsourceMessageRequestedEventInputsHandlePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventInputsCreate@4';

function IGCsourceMessageRequestedEventInputsAddRef
(
   Handle : TIGCsourceMessageRequestedEventInputsHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventInputsAddRef@4';

function IGCsourceMessageRequestedEventInputsRelease
(
   Handle : TIGCsourceMessageRequestedEventInputsHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventInputsRelease@4';

constructor TIGCsourceMessageRequestedEventInputs.Create();
begin
   inherited Create;
   FHandle := nil;
   DLLcheckResult(IGCsourceMessageRequestedEventInputsCreate(Addr(FHandle)));
end;

constructor TIGCsourceMessageRequestedEventInputs.CreateWithHandle(Handle : TIGCsourceMessageRequestedEventInputsHandle);
begin
   inherited Create;
   FHandle := Handle;
end;

function TIGCsourceMessageRequestedEventInputs._AddRef : Integer;
begin
   Result := inherited _AddRef;
   DLLcheckResult(IGCsourceMessageRequestedEventInputsAddRef(FHandle));
end;

function TIGCsourceMessageRequestedEventInputs._Release : Integer;
begin
   DLLcheckResult(IGCsourceMessageRequestedEventInputsRelease(FHandle));
Result := inherited _Release;
end;

destructor TIGCsourceMessageRequestedEventInputs.Destroy;
begin
   inherited Destroy;
end;

function IGCsourceMessageRequestedEventInputsCreateObject : IIGCsourceMessageRequestedEventInputs;
begin
   Result := TIGCsourceMessageRequestedEventInputs.Create();
end;

function IGCsourceMessageRequestedEventInputsCreateObjectWithHandle(Handle : TIGCsourceMessageRequestedEventInputsHandle) : IIGCsourceMessageRequestedEventInputs;
begin
   Result := TIGCsourceMessageRequestedEventInputs.CreateWithHandle(Handle);
end;

{: 
   This class is used to send response data from OnMessageRequested event handlers 
  back to Iguana. 
  
   Source plugins are provided with an instance of this class as an argument to 
  their OnMessageRequested event handler. The event handler uses the properties 
  and methods of the provided instance to craft a suitable response to send back 
  to Iguana. After the event handler returns, the response is sent back to Iguana.
   
  
   At a minimum, the event handler should set the OutboundMessage and 
  PluginMessageId properties to appropriate values. 
  
   The plugin event handler may request that the Iguana channel be stopped via the 
  StopChannelFlag, StopChannelErrorFlag and StopChannelReason properties. 
  
   The plugin event handler may add log messages to Iguana's logs using the 
  AddErrorLogMessage, AddWarningLogMessage, AddInfoLogMessage and 
  AddDebugLogMessage methods. 
  
}
type TIGCsourceMessageRequestedEventOutputs = class(TIGCiunknown, IIGCsourceMessageRequestedEventOutputs)
   private
      FHandle : TIGCsourceMessageRequestedEventOutputsHandle;
   public
      constructor Create;
      constructor CreateWithHandle(Handle : TIGCsourceMessageRequestedEventOutputsHandle);
      function _AddRef : Integer; override; stdcall;
      function _Release : Integer; override; stdcall;
      destructor Destroy; override;
      {$IFNDEF HIDE}
      
      {: 
         Message to send back to Iguana, or an empty string if a message is not 
        presently available. 
        
        See also the SetOutboundMessage method.
        
      }
      function GetOutboundMessage : AnsiString;
      
      {: 
        Set method for OutboundMessage.
        
        See OutboundMessage.
        
      }
      procedure SetOutboundMessage(Value : AnsiString);
      
      {: 
         Id to be assigned by the plugin to uniquely identify OutboundMessage. 
        
         Iguana sends the provided PluginMessageId back to the plugin's 
        OnMessageRequestCompleted event handler via PluginMessageId property. This 
        allows the plugin to associate each message request completed notification with 
        the message sent to Iguana. 
        
         The format of the PluginMessageId is to be determined by the plugin author. 
        Iguana does not interpret this value, other than by adding it to logs, and 
        sending it back to the plugin. 
        
        See also the SetPluginMessageId method.
        
      }
      function GetPluginMessageId : AnsiString;
      
      {: 
        Set method for PluginMessageId.
        
        See PluginMessageId.
        
      }
      procedure SetPluginMessageId(Value : AnsiString);
      
      {: 
         Requests that Iguana stop the channel to which the plugin is connected. 
        
         Default value: false. 
        
         See also: StopChannelErrorFlag and StopChannelReason. 
        
        See also the SetStopChannelFlag method.
        
      }
      function GetStopChannelFlag : Boolean;
      
      {: 
        Set method for StopChannelFlag.
        
        See StopChannelFlag.
        
      }
      procedure SetStopChannelFlag(Value : Boolean);
      
      {: 
         When combined with StopChannelFlag, requests that Iguana stop the channel with 
        the channel status set to 'error'. 
        
         Default value: false. 
        
         Only applicable if StopChannelFlag is set to true. 
        
        See also the SetStopChannelErrorFlag method.
        
      }
      function GetStopChannelErrorFlag : Boolean;
      
      {: 
        Set method for StopChannelErrorFlag.
        
        See StopChannelErrorFlag.
        
      }
      procedure SetStopChannelErrorFlag(Value : Boolean);
      
      {: 
         Describes the reason for the 'stop channel' request. 
        
         Only applicable if StopChannelFlag is set to true. 
        
        See also the SetStopChannelReason method.
        
      }
      function GetStopChannelReason : AnsiString;
      
      {: 
        Set method for StopChannelReason.
        
        See StopChannelReason.
        
      }
      procedure SetStopChannelReason(Value : AnsiString);
      {$ENDIF}
      
      {: 
         Adds an error log message to Iguana's logs. 
        
      }
      procedure AddErrorLogMessage(ErrorLogMessage : AnsiString);
      
      {: 
         Adds a warning log message to Iguana's logs. 
        
      }
      procedure AddWarningLogMessage(WarningLogMessage : AnsiString);
      
      {: 
         Adds an info log message to Iguana's logs. 
        
      }
      procedure AddInfoLogMessage(InfoLogMessage : AnsiString);
      
      {: 
         Adds a debug log message to Iguana's logs. 
        
      }
      procedure AddDebugLogMessage(DebugLogMessage : AnsiString);
      
      {: 
         Message to send back to Iguana, or an empty string if a message is not 
        presently available. 
        
      }
      property OutboundMessage : AnsiString read GetOutboundMessage write SetOutboundMessage;
      
      
      {: 
         Id to be assigned by the plugin to uniquely identify OutboundMessage. 
        
         Iguana sends the provided PluginMessageId back to the plugin's 
        OnMessageRequestCompleted event handler via PluginMessageId property. This 
        allows the plugin to associate each message request completed notification with 
        the message sent to Iguana. 
        
         The format of the PluginMessageId is to be determined by the plugin author. 
        Iguana does not interpret this value, other than by adding it to logs, and 
        sending it back to the plugin. 
        
      }
      property PluginMessageId : AnsiString read GetPluginMessageId write SetPluginMessageId;
      
      
      {: 
         Requests that Iguana stop the channel to which the plugin is connected. 
        
         Default value: false. 
        
         See also: StopChannelErrorFlag and StopChannelReason. 
        
      }
      property StopChannelFlag : Boolean read GetStopChannelFlag write SetStopChannelFlag;
      
      
      {: 
         When combined with StopChannelFlag, requests that Iguana stop the channel with 
        the channel status set to 'error'. 
        
         Default value: false. 
        
         Only applicable if StopChannelFlag is set to true. 
        
      }
      property StopChannelErrorFlag : Boolean read GetStopChannelErrorFlag write SetStopChannelErrorFlag;
      
      
      {: 
         Describes the reason for the 'stop channel' request. 
        
         Only applicable if StopChannelFlag is set to true. 
        
      }
      property StopChannelReason : AnsiString read GetStopChannelReason write SetStopChannelReason;
      
   end;
   
function IGCsourceMessageRequestedEventOutputsCreate
(
   ReturnValue : TIGCsourceMessageRequestedEventOutputsHandlePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsCreate@4';

function IGCsourceMessageRequestedEventOutputsAddRef
(
   Handle : TIGCsourceMessageRequestedEventOutputsHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsAddRef@4';

function IGCsourceMessageRequestedEventOutputsRelease
(
   Handle : TIGCsourceMessageRequestedEventOutputsHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsRelease@4';

function IGCsourceMessageRequestedEventOutputsGetOutboundMessage
(
   Handle : TIGCsourceMessageRequestedEventOutputsHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsGetOutboundMessage@8';

function IGCsourceMessageRequestedEventOutputsSetOutboundMessage
(
   Handle : TIGCsourceMessageRequestedEventOutputsHandle;
   Value : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsSetOutboundMessage@8';

function IGCsourceMessageRequestedEventOutputsGetPluginMessageId
(
   Handle : TIGCsourceMessageRequestedEventOutputsHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsGetPluginMessageId@8';

function IGCsourceMessageRequestedEventOutputsSetPluginMessageId
(
   Handle : TIGCsourceMessageRequestedEventOutputsHandle;
   Value : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsSetPluginMessageId@8';

function IGCsourceMessageRequestedEventOutputsGetStopChannelFlag
(
   Handle : TIGCsourceMessageRequestedEventOutputsHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsGetStopChannelFlag@8';

function IGCsourceMessageRequestedEventOutputsSetStopChannelFlag
(
   Handle : TIGCsourceMessageRequestedEventOutputsHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsSetStopChannelFlag@8';

function IGCsourceMessageRequestedEventOutputsGetStopChannelErrorFlag
(
   Handle : TIGCsourceMessageRequestedEventOutputsHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsGetStopChannelErrorFlag@8';

function IGCsourceMessageRequestedEventOutputsSetStopChannelErrorFlag
(
   Handle : TIGCsourceMessageRequestedEventOutputsHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsSetStopChannelErrorFlag@8';

function IGCsourceMessageRequestedEventOutputsGetStopChannelReason
(
   Handle : TIGCsourceMessageRequestedEventOutputsHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsGetStopChannelReason@8';

function IGCsourceMessageRequestedEventOutputsSetStopChannelReason
(
   Handle : TIGCsourceMessageRequestedEventOutputsHandle;
   Value : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsSetStopChannelReason@8';

function IGCsourceMessageRequestedEventOutputsAddErrorLogMessage
(
   Handle : TIGCsourceMessageRequestedEventOutputsHandle;
   ErrorLogMessage : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsAddErrorLogMessage@8';

function IGCsourceMessageRequestedEventOutputsAddWarningLogMessage
(
   Handle : TIGCsourceMessageRequestedEventOutputsHandle;
   WarningLogMessage : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsAddWarningLogMessage@8';

function IGCsourceMessageRequestedEventOutputsAddInfoLogMessage
(
   Handle : TIGCsourceMessageRequestedEventOutputsHandle;
   InfoLogMessage : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsAddInfoLogMessage@8';

function IGCsourceMessageRequestedEventOutputsAddDebugLogMessage
(
   Handle : TIGCsourceMessageRequestedEventOutputsHandle;
   DebugLogMessage : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestedEventOutputsAddDebugLogMessage@8';

constructor TIGCsourceMessageRequestedEventOutputs.Create();
begin
   inherited Create;
   FHandle := nil;
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsCreate(Addr(FHandle)));
end;

constructor TIGCsourceMessageRequestedEventOutputs.CreateWithHandle(Handle : TIGCsourceMessageRequestedEventOutputsHandle);
begin
   inherited Create;
   FHandle := Handle;
end;

function TIGCsourceMessageRequestedEventOutputs._AddRef : Integer;
begin
   Result := inherited _AddRef;
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsAddRef(FHandle));
end;

function TIGCsourceMessageRequestedEventOutputs._Release : Integer;
begin
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsRelease(FHandle));
Result := inherited _Release;
end;

destructor TIGCsourceMessageRequestedEventOutputs.Destroy;
begin
   inherited Destroy;
end;

function IGCsourceMessageRequestedEventOutputsCreateObject : IIGCsourceMessageRequestedEventOutputs;
begin
   Result := TIGCsourceMessageRequestedEventOutputs.Create();
end;

function IGCsourceMessageRequestedEventOutputsCreateObjectWithHandle(Handle : TIGCsourceMessageRequestedEventOutputsHandle) : IIGCsourceMessageRequestedEventOutputs;
begin
   Result := TIGCsourceMessageRequestedEventOutputs.CreateWithHandle(Handle);
end;

function TIGCsourceMessageRequestedEventOutputs.GetOutboundMessage : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsGetOutboundMessage(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGCsourceMessageRequestedEventOutputs.SetOutboundMessage
(
   Value : AnsiString
);
begin
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsSetOutboundMessage(FHandle, PAnsiChar(Value)));
end;

function TIGCsourceMessageRequestedEventOutputs.GetPluginMessageId : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsGetPluginMessageId(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGCsourceMessageRequestedEventOutputs.SetPluginMessageId
(
   Value : AnsiString
);
begin
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsSetPluginMessageId(FHandle, PAnsiChar(Value)));
end;

function TIGCsourceMessageRequestedEventOutputs.GetStopChannelFlag : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsGetStopChannelFlag(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGCsourceMessageRequestedEventOutputs.SetStopChannelFlag
(
   Value : Boolean
);
begin
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsSetStopChannelFlag(FHandle, Value));
end;

function TIGCsourceMessageRequestedEventOutputs.GetStopChannelErrorFlag : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsGetStopChannelErrorFlag(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGCsourceMessageRequestedEventOutputs.SetStopChannelErrorFlag
(
   Value : Boolean
);
begin
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsSetStopChannelErrorFlag(FHandle, Value));
end;

function TIGCsourceMessageRequestedEventOutputs.GetStopChannelReason : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsGetStopChannelReason(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGCsourceMessageRequestedEventOutputs.SetStopChannelReason
(
   Value : AnsiString
);
begin
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsSetStopChannelReason(FHandle, PAnsiChar(Value)));
end;

procedure TIGCsourceMessageRequestedEventOutputs.AddErrorLogMessage
(
   ErrorLogMessage : AnsiString
);
begin
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsAddErrorLogMessage(FHandle, PAnsiChar(ErrorLogMessage)));
end;

procedure TIGCsourceMessageRequestedEventOutputs.AddWarningLogMessage
(
   WarningLogMessage : AnsiString
);
begin
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsAddWarningLogMessage(FHandle, PAnsiChar(WarningLogMessage)));
end;

procedure TIGCsourceMessageRequestedEventOutputs.AddInfoLogMessage
(
   InfoLogMessage : AnsiString
);
begin
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsAddInfoLogMessage(FHandle, PAnsiChar(InfoLogMessage)));
end;

procedure TIGCsourceMessageRequestedEventOutputs.AddDebugLogMessage
(
   DebugLogMessage : AnsiString
);
begin
   DLLcheckResult(IGCsourceMessageRequestedEventOutputsAddDebugLogMessage(FHandle, PAnsiChar(DebugLogMessage)));
end;

{: 
   This class is used to pass data from Iguana to OnMessageRequestCompleted event 
  handlers. 
  
}
type TIGCsourceMessageRequestCompletedEventInputs = class(TIGCiunknown, IIGCsourceMessageRequestCompletedEventInputs)
   private
      FHandle : TIGCsourceMessageRequestCompletedEventInputsHandle;
   public
      constructor Create;
      constructor CreateWithHandle(Handle : TIGCsourceMessageRequestCompletedEventInputsHandle);
      function _AddRef : Integer; override; stdcall;
      function _Release : Integer; override; stdcall;
      destructor Destroy; override;
      {$IFNDEF HIDE}
      
      {: 
         Id assigned by the plugin's OnMessageRequested event handler via the 
        PluginMessageId property. This allows the plugin to associate each message 
        request completed notification with the message sent to Iguana. 
        
         The format of the PluginMessageId is to be determined by the plugin author. 
        Iguana does not interpret this value, other than by adding it to logs, and 
        sending it back to the plugin. 
        
      }
      function GetPluginMessageId : AnsiString;
      
      {: 
         Id assigned by Iguana uniquely identifying the generated message within 
        Iguana's logs. 
        
         The Message Log Id may be used to query Iguana for additional message-related 
        information. 
        
         See 
        
         http://www.interfaceware.com/manual/iguana4_using_message_id.html 
        
      }
      function GetMessageLogId : AnsiString;
      
      {: 
         Flag indicating whether or not message was processed by Iguana. 
        
         If true, the message has been processed by Iguana and does not need to be 
        resent. The plugin should respond to the next OnMessageRequested event with the 
        next available message. 
        
         If false, the message has not been processed by Iguana and needs to be resent. 
        The plugin should respond to the next OnMessageRequested event with the same 
        message. 
        
      }
      function GetMessageProcessed : Boolean;
      {$ENDIF}
      
      {: 
         Id assigned by the plugin's OnMessageRequested event handler via the 
        PluginMessageId property. This allows the plugin to associate each message 
        request completed notification with the message sent to Iguana. 
        
         The format of the PluginMessageId is to be determined by the plugin author. 
        Iguana does not interpret this value, other than by adding it to logs, and 
        sending it back to the plugin. 
        
      }
      property PluginMessageId : AnsiString read GetPluginMessageId;
      
      
      {: 
         Id assigned by Iguana uniquely identifying the generated message within 
        Iguana's logs. 
        
         The Message Log Id may be used to query Iguana for additional message-related 
        information. 
        
         See 
        
         http://www.interfaceware.com/manual/iguana4_using_message_id.html 
        
      }
      property MessageLogId : AnsiString read GetMessageLogId;
      
      
      {: 
         Flag indicating whether or not message was processed by Iguana. 
        
         If true, the message has been processed by Iguana and does not need to be 
        resent. The plugin should respond to the next OnMessageRequested event with the 
        next available message. 
        
         If false, the message has not been processed by Iguana and needs to be resent. 
        The plugin should respond to the next OnMessageRequested event with the same 
        message. 
        
      }
      property MessageProcessed : Boolean read GetMessageProcessed;
      
   end;
   
function IGCsourceMessageRequestCompletedEventInputsCreate
(
   ReturnValue : TIGCsourceMessageRequestCompletedEventInputsHandlePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestCompletedEventInputsCreate@4';

function IGCsourceMessageRequestCompletedEventInputsAddRef
(
   Handle : TIGCsourceMessageRequestCompletedEventInputsHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestCompletedEventInputsAddRef@4';

function IGCsourceMessageRequestCompletedEventInputsRelease
(
   Handle : TIGCsourceMessageRequestCompletedEventInputsHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestCompletedEventInputsRelease@4';

function IGCsourceMessageRequestCompletedEventInputsGetPluginMessageId
(
   Handle : TIGCsourceMessageRequestCompletedEventInputsHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestCompletedEventInputsGetPluginMessageId@8';

function IGCsourceMessageRequestCompletedEventInputsGetMessageLogId
(
   Handle : TIGCsourceMessageRequestCompletedEventInputsHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestCompletedEventInputsGetMessageLogId@8';

function IGCsourceMessageRequestCompletedEventInputsGetMessageProcessed
(
   Handle : TIGCsourceMessageRequestCompletedEventInputsHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestCompletedEventInputsGetMessageProcessed@8';

constructor TIGCsourceMessageRequestCompletedEventInputs.Create();
begin
   inherited Create;
   FHandle := nil;
   DLLcheckResult(IGCsourceMessageRequestCompletedEventInputsCreate(Addr(FHandle)));
end;

constructor TIGCsourceMessageRequestCompletedEventInputs.CreateWithHandle(Handle : TIGCsourceMessageRequestCompletedEventInputsHandle);
begin
   inherited Create;
   FHandle := Handle;
end;

function TIGCsourceMessageRequestCompletedEventInputs._AddRef : Integer;
begin
   Result := inherited _AddRef;
   DLLcheckResult(IGCsourceMessageRequestCompletedEventInputsAddRef(FHandle));
end;

function TIGCsourceMessageRequestCompletedEventInputs._Release : Integer;
begin
   DLLcheckResult(IGCsourceMessageRequestCompletedEventInputsRelease(FHandle));
Result := inherited _Release;
end;

destructor TIGCsourceMessageRequestCompletedEventInputs.Destroy;
begin
   inherited Destroy;
end;

function IGCsourceMessageRequestCompletedEventInputsCreateObject : IIGCsourceMessageRequestCompletedEventInputs;
begin
   Result := TIGCsourceMessageRequestCompletedEventInputs.Create();
end;

function IGCsourceMessageRequestCompletedEventInputsCreateObjectWithHandle(Handle : TIGCsourceMessageRequestCompletedEventInputsHandle) : IIGCsourceMessageRequestCompletedEventInputs;
begin
   Result := TIGCsourceMessageRequestCompletedEventInputs.CreateWithHandle(Handle);
end;

function TIGCsourceMessageRequestCompletedEventInputs.GetPluginMessageId : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGCsourceMessageRequestCompletedEventInputsGetPluginMessageId(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGCsourceMessageRequestCompletedEventInputs.GetMessageLogId : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGCsourceMessageRequestCompletedEventInputsGetMessageLogId(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGCsourceMessageRequestCompletedEventInputs.GetMessageProcessed : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGCsourceMessageRequestCompletedEventInputsGetMessageProcessed(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

{: 
   This class is used to send response data from OnMessageRequestCompleted event 
  handlers back to Iguana. 
  
   At present, no data is actually sent back to Iguana from 
  OnMessageRequestCompleted event handlers. 
  
   This class is provided for future extensibility. 
  
}
type TIGCsourceMessageRequestCompletedEventOutputs = class(TIGCiunknown, IIGCsourceMessageRequestCompletedEventOutputs)
   private
      FHandle : TIGCsourceMessageRequestCompletedEventOutputsHandle;
   public
      constructor Create;
      constructor CreateWithHandle(Handle : TIGCsourceMessageRequestCompletedEventOutputsHandle);
      function _AddRef : Integer; override; stdcall;
      function _Release : Integer; override; stdcall;
      destructor Destroy; override;
      {$IFNDEF HIDE}
      {$ENDIF}
   end;
   
function IGCsourceMessageRequestCompletedEventOutputsCreate
(
   ReturnValue : TIGCsourceMessageRequestCompletedEventOutputsHandlePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestCompletedEventOutputsCreate@4';

function IGCsourceMessageRequestCompletedEventOutputsAddRef
(
   Handle : TIGCsourceMessageRequestCompletedEventOutputsHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestCompletedEventOutputsAddRef@4';

function IGCsourceMessageRequestCompletedEventOutputsRelease
(
   Handle : TIGCsourceMessageRequestCompletedEventOutputsHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceMessageRequestCompletedEventOutputsRelease@4';

constructor TIGCsourceMessageRequestCompletedEventOutputs.Create();
begin
   inherited Create;
   FHandle := nil;
   DLLcheckResult(IGCsourceMessageRequestCompletedEventOutputsCreate(Addr(FHandle)));
end;

constructor TIGCsourceMessageRequestCompletedEventOutputs.CreateWithHandle(Handle : TIGCsourceMessageRequestCompletedEventOutputsHandle);
begin
   inherited Create;
   FHandle := Handle;
end;

function TIGCsourceMessageRequestCompletedEventOutputs._AddRef : Integer;
begin
   Result := inherited _AddRef;
   DLLcheckResult(IGCsourceMessageRequestCompletedEventOutputsAddRef(FHandle));
end;

function TIGCsourceMessageRequestCompletedEventOutputs._Release : Integer;
begin
   DLLcheckResult(IGCsourceMessageRequestCompletedEventOutputsRelease(FHandle));
Result := inherited _Release;
end;

destructor TIGCsourceMessageRequestCompletedEventOutputs.Destroy;
begin
   inherited Destroy;
end;

function IGCsourceMessageRequestCompletedEventOutputsCreateObject : IIGCsourceMessageRequestCompletedEventOutputs;
begin
   Result := TIGCsourceMessageRequestCompletedEventOutputs.Create();
end;

function IGCsourceMessageRequestCompletedEventOutputsCreateObjectWithHandle(Handle : TIGCsourceMessageRequestCompletedEventOutputsHandle) : IIGCsourceMessageRequestCompletedEventOutputs;
begin
   Result := TIGCsourceMessageRequestCompletedEventOutputs.CreateWithHandle(Handle);
end;

{: 
   This class is used to pass data from Iguana to OnMessageReceived and 
  OnResubmissionPreviewMessageReceived event handlers. 
  
}
type TIGCdestinationMessageReceivedEventInputs = class(TIGCiunknown, IIGCdestinationMessageReceivedEventInputs)
   private
      FHandle : TIGCdestinationMessageReceivedEventInputsHandle;
   public
      constructor Create;
      constructor CreateWithHandle(Handle : TIGCdestinationMessageReceivedEventInputsHandle);
      function _AddRef : Integer; override; stdcall;
      function _Release : Integer; override; stdcall;
      destructor Destroy; override;
      {$IFNDEF HIDE}
      
      {: 
         Message received from Iguana. 
        
      }
      function GetMessage : AnsiString;
      
      {: 
         Id assigned by Iguana uniquely identifying the received message within Iguana's 
        logs. 
        
         The Message Log Id may be used to query Iguana for additional message-related 
        information. 
        
         See 
        
         http://www.interfaceware.com/manual/iguana4_using_message_id.html 
        
         Note that Message Log Ids are not supplied to 
        OnResubmissionPreviewMessageReceived events, since Iguana does not assign 
        Message Log Ids to resubmission preview messages. 
        
      }
      function GetMessageLogId : AnsiString;
      {$ENDIF}
      
      {: 
         Message received from Iguana. 
        
      }
      property Message : AnsiString read GetMessage;
      
      
      {: 
         Id assigned by Iguana uniquely identifying the received message within Iguana's 
        logs. 
        
         The Message Log Id may be used to query Iguana for additional message-related 
        information. 
        
         See 
        
         http://www.interfaceware.com/manual/iguana4_using_message_id.html 
        
         Note that Message Log Ids are not supplied to 
        OnResubmissionPreviewMessageReceived events, since Iguana does not assign 
        Message Log Ids to resubmission preview messages. 
        
      }
      property MessageLogId : AnsiString read GetMessageLogId;
      
   end;
   
function IGCdestinationMessageReceivedEventInputsCreate
(
   ReturnValue : TIGCdestinationMessageReceivedEventInputsHandlePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventInputsCreate@4';

function IGCdestinationMessageReceivedEventInputsAddRef
(
   Handle : TIGCdestinationMessageReceivedEventInputsHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventInputsAddRef@4';

function IGCdestinationMessageReceivedEventInputsRelease
(
   Handle : TIGCdestinationMessageReceivedEventInputsHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventInputsRelease@4';

function IGCdestinationMessageReceivedEventInputsGetMessage
(
   Handle : TIGCdestinationMessageReceivedEventInputsHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventInputsGetMessage@8';

function IGCdestinationMessageReceivedEventInputsGetMessageLogId
(
   Handle : TIGCdestinationMessageReceivedEventInputsHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventInputsGetMessageLogId@8';

constructor TIGCdestinationMessageReceivedEventInputs.Create();
begin
   inherited Create;
   FHandle := nil;
   DLLcheckResult(IGCdestinationMessageReceivedEventInputsCreate(Addr(FHandle)));
end;

constructor TIGCdestinationMessageReceivedEventInputs.CreateWithHandle(Handle : TIGCdestinationMessageReceivedEventInputsHandle);
begin
   inherited Create;
   FHandle := Handle;
end;

function TIGCdestinationMessageReceivedEventInputs._AddRef : Integer;
begin
   Result := inherited _AddRef;
   DLLcheckResult(IGCdestinationMessageReceivedEventInputsAddRef(FHandle));
end;

function TIGCdestinationMessageReceivedEventInputs._Release : Integer;
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventInputsRelease(FHandle));
Result := inherited _Release;
end;

destructor TIGCdestinationMessageReceivedEventInputs.Destroy;
begin
   inherited Destroy;
end;

function IGCdestinationMessageReceivedEventInputsCreateObject : IIGCdestinationMessageReceivedEventInputs;
begin
   Result := TIGCdestinationMessageReceivedEventInputs.Create();
end;

function IGCdestinationMessageReceivedEventInputsCreateObjectWithHandle(Handle : TIGCdestinationMessageReceivedEventInputsHandle) : IIGCdestinationMessageReceivedEventInputs;
begin
   Result := TIGCdestinationMessageReceivedEventInputs.CreateWithHandle(Handle);
end;

function TIGCdestinationMessageReceivedEventInputs.GetMessage : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventInputsGetMessage(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGCdestinationMessageReceivedEventInputs.GetMessageLogId : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventInputsGetMessageLogId(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

{: 
   This class is used to send response data from OnMessageReceived event handlers 
  back to Iguana. 
  
   Destination plugins are provided with an instance of this class as an argument 
  to their OnMessageReceived event handler. The event handler uses the properties 
  and methods of the provided instance to craft a suitable response to send back 
  to Iguana. After the event handler returns, the response is sent back to Iguana.
   
  
   At a minimum, the event handler should set the MessageProcessedFlag property to 
  true to indicate to Iguana that the message was received and processed by the 
  plugin. Setting this property to false will simply result in Iguana logging a 
  generic error message; it will not result in Iguana resending the message or 
  stopping the channel. Plugins can achieve more sophisticated and precise error 
  handling using the properties and methods described below. 
  
   If the event handler is unable to complete processing in a timely fashion, it 
  should use the ResendMessageFlag and ResendMessageDelay properties to request 
  that Iguana resend the message. This ensures that Iguana does not time-out the 
  connection to the plugin due to inactivity. The exact duration of the time-out 
  is determined by the Plugin Time field value configured for the To Plugin 
  channel component to which the plugin is connected. 
  
   The plugin event handler may request that the Iguana channel be stopped via the 
  StopChannelFlag, StopChannelErrorFlag and StopChannelReason properties. 
  
   The plugin event handler may add log messages to Iguana's logs using the 
  AddErrorLogMessage, AddWarningLogMessage, AddInfoLogMessage and 
  AddDebugLogMessage methods. 
  
}
type TIGCdestinationMessageReceivedEventOutputs = class(TIGCiunknown, IIGCdestinationMessageReceivedEventOutputs)
   private
      FHandle : TIGCdestinationMessageReceivedEventOutputsHandle;
   public
      constructor Create;
      constructor CreateWithHandle(Handle : TIGCdestinationMessageReceivedEventOutputsHandle);
      function _AddRef : Integer; override; stdcall;
      function _Release : Integer; override; stdcall;
      destructor Destroy; override;
      {$IFNDEF HIDE}
      
      {: 
         Indicates to Iguana whether or not the message was processed by the plugin. 
        
         Default value: false. 
        
         Should generally be set by event handlers to true. 
        
         If set to false, Iguana will simply issue a relatively generic error message. 
        Event handlers can add their own specific error log message to the Iguana logs 
        using the AddErrorLogMessage method instead. 
        
        See also the SetMessageProcessedFlag method.
        
      }
      function GetMessageProcessedFlag : Boolean;
      
      {: 
        Set method for MessageProcessedFlag.
        
        See MessageProcessedFlag.
        
      }
      procedure SetMessageProcessedFlag(Value : Boolean);
      
      {: 
         Requests that Iguana resend the message. 
        
         Default value: false. 
        
         The message will be resent after the delay specified by ResendMessageDelay. 
        
         If the channel is stopped, the message will be resent once the channel is 
        restarted. 
        
        See also the SetResendMessageFlag method.
        
      }
      function GetResendMessageFlag : Boolean;
      
      {: 
        Set method for ResendMessageFlag.
        
        See ResendMessageFlag.
        
      }
      procedure SetResendMessageFlag(Value : Boolean);
      
      {: 
         Specifies the delay time in milliseconds that Iguana should wait before 
        resending the message. 
        
         Default value: 0 milliseconds. 
        
         Only applicable if ResendMessageFlag is set to true. 
        
        See also the SetResendMessageDelay method.
        
      }
      function GetResendMessageDelay : Integer;
      
      {: 
        Set method for ResendMessageDelay.
        
        See ResendMessageDelay.
        
      }
      procedure SetResendMessageDelay(Value : Integer);
      
      {: 
         Requests that Iguana stop the channel to which the plugin is connected. 
        
         Default value: false. 
        
         See also: StopChannelErrorFlag and StopChannelReason. 
        
        See also the SetStopChannelFlag method.
        
      }
      function GetStopChannelFlag : Boolean;
      
      {: 
        Set method for StopChannelFlag.
        
        See StopChannelFlag.
        
      }
      procedure SetStopChannelFlag(Value : Boolean);
      
      {: 
         When combined with StopChannelFlag, requests that Iguana stop the channel with 
        the channel status set to 'error'. 
        
         Default value: false. 
        
         Only applicable if StopChannelFlag is set to true. 
        
        See also the SetStopChannelErrorFlag method.
        
      }
      function GetStopChannelErrorFlag : Boolean;
      
      {: 
        Set method for StopChannelErrorFlag.
        
        See StopChannelErrorFlag.
        
      }
      procedure SetStopChannelErrorFlag(Value : Boolean);
      
      {: 
         Describes the reason for the 'stop channel' request. 
        
         Only applicable if StopChannelFlag is set to true. 
        
        See also the SetStopChannelReason method.
        
      }
      function GetStopChannelReason : AnsiString;
      
      {: 
        Set method for StopChannelReason.
        
        See StopChannelReason.
        
      }
      procedure SetStopChannelReason(Value : AnsiString);
      {$ENDIF}
      
      {: 
         Adds an error log message to Iguana's logs. 
        
      }
      procedure AddErrorLogMessage(ErrorLogMessage : AnsiString);
      
      {: 
         Adds a warning log message to Iguana's logs. 
        
      }
      procedure AddWarningLogMessage(WarningLogMessage : AnsiString);
      
      {: 
         Adds an info log message to Iguana's logs. 
        
      }
      procedure AddInfoLogMessage(InfoLogMessage : AnsiString);
      
      {: 
         Adds a debug log message to Iguana's logs. 
        
      }
      procedure AddDebugLogMessage(DebugLogMessage : AnsiString);
      
      {: 
         Indicates to Iguana whether or not the message was processed by the plugin. 
        
         Default value: false. 
        
         Should generally be set by event handlers to true. 
        
         If set to false, Iguana will simply issue a relatively generic error message. 
        Event handlers can add their own specific error log message to the Iguana logs 
        using the AddErrorLogMessage method instead. 
        
      }
      property MessageProcessedFlag : Boolean read GetMessageProcessedFlag write SetMessageProcessedFlag;
      
      
      {: 
         Requests that Iguana resend the message. 
        
         Default value: false. 
        
         The message will be resent after the delay specified by ResendMessageDelay. 
        
         If the channel is stopped, the message will be resent once the channel is 
        restarted. 
        
      }
      property ResendMessageFlag : Boolean read GetResendMessageFlag write SetResendMessageFlag;
      
      
      {: 
         Specifies the delay time in milliseconds that Iguana should wait before 
        resending the message. 
        
         Default value: 0 milliseconds. 
        
         Only applicable if ResendMessageFlag is set to true. 
        
      }
      property ResendMessageDelay : Integer read GetResendMessageDelay write SetResendMessageDelay;
      
      
      {: 
         Requests that Iguana stop the channel to which the plugin is connected. 
        
         Default value: false. 
        
         See also: StopChannelErrorFlag and StopChannelReason. 
        
      }
      property StopChannelFlag : Boolean read GetStopChannelFlag write SetStopChannelFlag;
      
      
      {: 
         When combined with StopChannelFlag, requests that Iguana stop the channel with 
        the channel status set to 'error'. 
        
         Default value: false. 
        
         Only applicable if StopChannelFlag is set to true. 
        
      }
      property StopChannelErrorFlag : Boolean read GetStopChannelErrorFlag write SetStopChannelErrorFlag;
      
      
      {: 
         Describes the reason for the 'stop channel' request. 
        
         Only applicable if StopChannelFlag is set to true. 
        
      }
      property StopChannelReason : AnsiString read GetStopChannelReason write SetStopChannelReason;
      
   end;
   
function IGCdestinationMessageReceivedEventOutputsCreate
(
   ReturnValue : TIGCdestinationMessageReceivedEventOutputsHandlePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsCreate@4';

function IGCdestinationMessageReceivedEventOutputsAddRef
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsAddRef@4';

function IGCdestinationMessageReceivedEventOutputsRelease
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsRelease@4';

function IGCdestinationMessageReceivedEventOutputsGetMessageProcessedFlag
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsGetMessageProcessedFlag@8';

function IGCdestinationMessageReceivedEventOutputsSetMessageProcessedFlag
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsSetMessageProcessedFlag@8';

function IGCdestinationMessageReceivedEventOutputsGetResendMessageFlag
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsGetResendMessageFlag@8';

function IGCdestinationMessageReceivedEventOutputsSetResendMessageFlag
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsSetResendMessageFlag@8';

function IGCdestinationMessageReceivedEventOutputsGetResendMessageDelay
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle;
   ReturnValue : TIntegerPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsGetResendMessageDelay@8';

function IGCdestinationMessageReceivedEventOutputsSetResendMessageDelay
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle;
   Value : Integer
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsSetResendMessageDelay@8';

function IGCdestinationMessageReceivedEventOutputsGetStopChannelFlag
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsGetStopChannelFlag@8';

function IGCdestinationMessageReceivedEventOutputsSetStopChannelFlag
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsSetStopChannelFlag@8';

function IGCdestinationMessageReceivedEventOutputsGetStopChannelErrorFlag
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsGetStopChannelErrorFlag@8';

function IGCdestinationMessageReceivedEventOutputsSetStopChannelErrorFlag
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsSetStopChannelErrorFlag@8';

function IGCdestinationMessageReceivedEventOutputsGetStopChannelReason
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsGetStopChannelReason@8';

function IGCdestinationMessageReceivedEventOutputsSetStopChannelReason
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle;
   Value : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsSetStopChannelReason@8';

function IGCdestinationMessageReceivedEventOutputsAddErrorLogMessage
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle;
   ErrorLogMessage : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsAddErrorLogMessage@8';

function IGCdestinationMessageReceivedEventOutputsAddWarningLogMessage
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle;
   WarningLogMessage : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsAddWarningLogMessage@8';

function IGCdestinationMessageReceivedEventOutputsAddInfoLogMessage
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle;
   InfoLogMessage : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsAddInfoLogMessage@8';

function IGCdestinationMessageReceivedEventOutputsAddDebugLogMessage
(
   Handle : TIGCdestinationMessageReceivedEventOutputsHandle;
   DebugLogMessage : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationMessageReceivedEventOutputsAddDebugLogMessage@8';

constructor TIGCdestinationMessageReceivedEventOutputs.Create();
begin
   inherited Create;
   FHandle := nil;
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsCreate(Addr(FHandle)));
end;

constructor TIGCdestinationMessageReceivedEventOutputs.CreateWithHandle(Handle : TIGCdestinationMessageReceivedEventOutputsHandle);
begin
   inherited Create;
   FHandle := Handle;
end;

function TIGCdestinationMessageReceivedEventOutputs._AddRef : Integer;
begin
   Result := inherited _AddRef;
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsAddRef(FHandle));
end;

function TIGCdestinationMessageReceivedEventOutputs._Release : Integer;
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsRelease(FHandle));
Result := inherited _Release;
end;

destructor TIGCdestinationMessageReceivedEventOutputs.Destroy;
begin
   inherited Destroy;
end;

function IGCdestinationMessageReceivedEventOutputsCreateObject : IIGCdestinationMessageReceivedEventOutputs;
begin
   Result := TIGCdestinationMessageReceivedEventOutputs.Create();
end;

function IGCdestinationMessageReceivedEventOutputsCreateObjectWithHandle(Handle : TIGCdestinationMessageReceivedEventOutputsHandle) : IIGCdestinationMessageReceivedEventOutputs;
begin
   Result := TIGCdestinationMessageReceivedEventOutputs.CreateWithHandle(Handle);
end;

function TIGCdestinationMessageReceivedEventOutputs.GetMessageProcessedFlag : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsGetMessageProcessedFlag(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGCdestinationMessageReceivedEventOutputs.SetMessageProcessedFlag
(
   Value : Boolean
);
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsSetMessageProcessedFlag(FHandle, Value));
end;

function TIGCdestinationMessageReceivedEventOutputs.GetResendMessageFlag : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsGetResendMessageFlag(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGCdestinationMessageReceivedEventOutputs.SetResendMessageFlag
(
   Value : Boolean
);
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsSetResendMessageFlag(FHandle, Value));
end;

function TIGCdestinationMessageReceivedEventOutputs.GetResendMessageDelay : Integer;
var
   ResultValue : Integer;
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsGetResendMessageDelay(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGCdestinationMessageReceivedEventOutputs.SetResendMessageDelay
(
   Value : Integer
);
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsSetResendMessageDelay(FHandle, Value));
end;

function TIGCdestinationMessageReceivedEventOutputs.GetStopChannelFlag : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsGetStopChannelFlag(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGCdestinationMessageReceivedEventOutputs.SetStopChannelFlag
(
   Value : Boolean
);
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsSetStopChannelFlag(FHandle, Value));
end;

function TIGCdestinationMessageReceivedEventOutputs.GetStopChannelErrorFlag : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsGetStopChannelErrorFlag(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGCdestinationMessageReceivedEventOutputs.SetStopChannelErrorFlag
(
   Value : Boolean
);
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsSetStopChannelErrorFlag(FHandle, Value));
end;

function TIGCdestinationMessageReceivedEventOutputs.GetStopChannelReason : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsGetStopChannelReason(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGCdestinationMessageReceivedEventOutputs.SetStopChannelReason
(
   Value : AnsiString
);
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsSetStopChannelReason(FHandle, PAnsiChar(Value)));
end;

procedure TIGCdestinationMessageReceivedEventOutputs.AddErrorLogMessage
(
   ErrorLogMessage : AnsiString
);
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsAddErrorLogMessage(FHandle, PAnsiChar(ErrorLogMessage)));
end;

procedure TIGCdestinationMessageReceivedEventOutputs.AddWarningLogMessage
(
   WarningLogMessage : AnsiString
);
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsAddWarningLogMessage(FHandle, PAnsiChar(WarningLogMessage)));
end;

procedure TIGCdestinationMessageReceivedEventOutputs.AddInfoLogMessage
(
   InfoLogMessage : AnsiString
);
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsAddInfoLogMessage(FHandle, PAnsiChar(InfoLogMessage)));
end;

procedure TIGCdestinationMessageReceivedEventOutputs.AddDebugLogMessage
(
   DebugLogMessage : AnsiString
);
begin
   DLLcheckResult(IGCdestinationMessageReceivedEventOutputsAddDebugLogMessage(FHandle, PAnsiChar(DebugLogMessage)));
end;

{: 
   This class is used to describe the reason for a plugin's disconnection from 
  Iguana. 
  
   The IIGCdisconnectReason for a plugin's most recent disconnection from Iguana 
  may be retrieved from the DisconnectReason or DisconnectReason properties, 
  depending on the type of the plugin. 
  
   The disconnect reason includes three mutually exclusive flags indicating the 
  reason for the disconnection: DueToIguana, DueToPlugin, and DueToError. These 
  flags can be used programmatically to customize plugin disconnection handling 
  depending on the cause of the disconnection. 
  
   The disconnect reason includes a textual description of the reason for 
  disconnection: Description. The textual description may contain additional 
  details useful in diagnosing unexpected disconnections, especially in the case 
  of disconnection due to errors. 
  
}
type TIGCdisconnectReason = class(TIGCiunknown, IIGCdisconnectReason)
   private
      FHandle : TIGCdisconnectReasonHandle;
   public
      constructor Create;
      constructor CreateWithHandle(Handle : TIGCdisconnectReasonHandle);
      function _AddRef : Integer; override; stdcall;
      function _Release : Integer; override; stdcall;
      destructor Destroy; override;
      {$IFNDEF HIDE}
      
      {: 
         Indicates that Iguana closed the connection with the plugin. 
        
         Iguana closes its connection with a plugin when stopping the plugin channel. 
        
      }
      function GetDueToIguana : Boolean;
      
      {: 
         Indicates that the plugin requested disconnection from Iguana. 
        
         Plugins may request disconnection by invoking the Disconnect or Disconnect 
        methods, depending on the type of plugin. 
        
      }
      function GetDueToPlugin : Boolean;
      
      {: 
         Indicates that the connection between Iguana and the plugin was closed due to 
        an error. 
        
         A textual description of the error is available via the Description property. 
        
      }
      function GetDueToError : Boolean;
      
      {: 
         Provides a textual description of the reason for disconnection. 
        
      }
      function GetDescription : AnsiString;
      {$ENDIF}
      
      {: 
         Indicates that Iguana closed the connection with the plugin. 
        
         Iguana closes its connection with a plugin when stopping the plugin channel. 
        
      }
      property DueToIguana : Boolean read GetDueToIguana;
      
      
      {: 
         Indicates that the plugin requested disconnection from Iguana. 
        
         Plugins may request disconnection by invoking the Disconnect or Disconnect 
        methods, depending on the type of plugin. 
        
      }
      property DueToPlugin : Boolean read GetDueToPlugin;
      
      
      {: 
         Indicates that the connection between Iguana and the plugin was closed due to 
        an error. 
        
         A textual description of the error is available via the Description property. 
        
      }
      property DueToError : Boolean read GetDueToError;
      
      
      {: 
         Provides a textual description of the reason for disconnection. 
        
      }
      property Description : AnsiString read GetDescription;
      
   end;
   
function IGCdisconnectReasonCreate
(
   ReturnValue : TIGCdisconnectReasonHandlePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdisconnectReasonCreate@4';

function IGCdisconnectReasonAddRef
(
   Handle : TIGCdisconnectReasonHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdisconnectReasonAddRef@4';

function IGCdisconnectReasonRelease
(
   Handle : TIGCdisconnectReasonHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdisconnectReasonRelease@4';

function IGCdisconnectReasonGetDueToIguana
(
   Handle : TIGCdisconnectReasonHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdisconnectReasonGetDueToIguana@8';

function IGCdisconnectReasonGetDueToPlugin
(
   Handle : TIGCdisconnectReasonHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdisconnectReasonGetDueToPlugin@8';

function IGCdisconnectReasonGetDueToError
(
   Handle : TIGCdisconnectReasonHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdisconnectReasonGetDueToError@8';

function IGCdisconnectReasonGetDescription
(
   Handle : TIGCdisconnectReasonHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdisconnectReasonGetDescription@8';

constructor TIGCdisconnectReason.Create();
begin
   inherited Create;
   FHandle := nil;
   DLLcheckResult(IGCdisconnectReasonCreate(Addr(FHandle)));
end;

constructor TIGCdisconnectReason.CreateWithHandle(Handle : TIGCdisconnectReasonHandle);
begin
   inherited Create;
   FHandle := Handle;
end;

function TIGCdisconnectReason._AddRef : Integer;
begin
   Result := inherited _AddRef;
   DLLcheckResult(IGCdisconnectReasonAddRef(FHandle));
end;

function TIGCdisconnectReason._Release : Integer;
begin
   DLLcheckResult(IGCdisconnectReasonRelease(FHandle));
Result := inherited _Release;
end;

destructor TIGCdisconnectReason.Destroy;
begin
   inherited Destroy;
end;

function IGCdisconnectReasonCreateObject : IIGCdisconnectReason;
begin
   Result := TIGCdisconnectReason.Create();
end;

function IGCdisconnectReasonCreateObjectWithHandle(Handle : TIGCdisconnectReasonHandle) : IIGCdisconnectReason;
begin
   Result := TIGCdisconnectReason.CreateWithHandle(Handle);
end;

function TIGCdisconnectReason.GetDueToIguana : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGCdisconnectReasonGetDueToIguana(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGCdisconnectReason.GetDueToPlugin : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGCdisconnectReasonGetDueToPlugin(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGCdisconnectReason.GetDueToError : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGCdisconnectReasonGetDueToError(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGCdisconnectReason.GetDescription : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGCdisconnectReasonGetDescription(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function IGCsourceCreate
(
   ReturnValue : TIGCsourceHandlePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceCreate@4';

function IGCsourceAddRef
(
   Handle : TIGCsourceHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceAddRef@4';

function IGCsourceRelease
(
   Handle : TIGCsourceHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceRelease@4';

function IGCsourceAddListener
(
   Handle : TIGCsourceHandle;
   pListener : Pointer
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceAddListener@8';

function IGCsourceRemoveListener
(
   Handle : TIGCsourceHandle;
   pListener : Pointer
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceRemoveListener@8';

function IGCsourceGetDisconnectReason
(
   Handle : TIGCsourceHandle;
   ReturnValue : TIGCdisconnectReasonHandlePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceGetDisconnectReason@8';

function IGCsourceGetConnectTimeout
(
   Handle : TIGCsourceHandle;
   ReturnValue : TIntegerPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceGetConnectTimeout@8';

function IGCsourceSetConnectTimeout
(
   Handle : TIGCsourceHandle;
   Value : Integer
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceSetConnectTimeout@8';

function IGCsourceEnableDebugLogging
(
   Handle : TIGCsourceHandle;
   FileName : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceEnableDebugLogging@8';

function IGCsourceConnect
(
   Handle : TIGCsourceHandle;
   HostName : PAnsiChar;
   PortNumber : Integer;
   ChannelName : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceConnect@16';

function IGCsourceDisconnect
(
   Handle : TIGCsourceHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceDisconnect@4';

function IGCsourceWaitForDisconnect
(
   Handle : TIGCsourceHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceWaitForDisconnect@4';

function IGCsourceWaitForDisconnectWithTimeout
(
   Handle : TIGCsourceHandle;
   TimeoutInMilliseconds : Integer;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCsourceWaitForDisconnectWithTimeout@12';

type TIGCsourceOnMessageRequestedCallback = function
(
   Handle : TIGCsource;
   Inputs : TIGCsourceMessageRequestedEventInputsHandle;
   Outputs : TIGCsourceMessageRequestedEventOutputsHandle
) : TIGCresultHandle; stdcall;

function IGCsourceSetMessageRequestedCallback(Callback : TIGCsourceOnMessageRequestedCallback)
: TIGCresultHandle; stdcall; external 'IGC.dll' name '_IGCsourceSetMessageRequestedCallback@4';

type TIGCsourceOnMessageRequestCompletedCallback = function
(
   Handle : TIGCsource;
   Inputs : TIGCsourceMessageRequestCompletedEventInputsHandle;
   Outputs : TIGCsourceMessageRequestCompletedEventOutputsHandle
) : TIGCresultHandle; stdcall;

function IGCsourceSetMessageRequestCompletedCallback(Callback : TIGCsourceOnMessageRequestCompletedCallback)
: TIGCresultHandle; stdcall; external 'IGC.dll' name '_IGCsourceSetMessageRequestCompletedCallback@4';

type TIGCsourceOnDisconnectedCallback = function
(
   Handle : TIGCsource
) : TIGCresultHandle; stdcall;

function IGCsourceSetDisconnectedCallback(Callback : TIGCsourceOnDisconnectedCallback)
: TIGCresultHandle; stdcall; external 'IGC.dll' name '_IGCsourceSetDisconnectedCallback@4';

constructor TIGCsource.Create(Owner: TComponent);
begin
   FHandle := nil;
   inherited Create(Owner);
   DLLcheckResult(IGCsourceCreate(Addr(FHandle)));
   DLLcheckResult(IGCsourceAddRef(FHandle));
   DLLcheckResult(IGCsourceAddListener(FHandle, Self));
end;

destructor TIGCsource.Destroy;
begin
   DLLcheckResult(IGCsourceRemoveListener(FHandle, Self));
   DLLcheckResult(IGCsourceRelease(FHandle));
   inherited Destroy;
end;

function TIGCsource.GetDisconnectReason : IIGCdisconnectReason;
var
   ResultValue : TIGCdisconnectReasonHandle;
begin
   DLLcheckResult(IGCsourceGetDisconnectReason(FHandle, Addr(ResultValue)));
   Result := IGCdisconnectReasonCreateObjectWithHandle(ResultValue);
end;

function TIGCsource.GetConnectTimeout : Integer;
var
   ResultValue : Integer;
begin
   DLLcheckResult(IGCsourceGetConnectTimeout(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGCsource.SetConnectTimeout
(
   Value : Integer
);
begin
   DLLcheckResult(IGCsourceSetConnectTimeout(FHandle, Value));
end;

procedure TIGCsource.EnableDebugLogging
(
   FileName : AnsiString
);
begin
   DLLcheckResult(IGCsourceEnableDebugLogging(FHandle, PAnsiChar(FileName)));
end;

procedure TIGCsource.Connect
(
   HostName : AnsiString; PortNumber : Integer; ChannelName : AnsiString
);
begin
   DLLcheckResult(IGCsourceConnect(FHandle, PAnsiChar(HostName), PortNumber, PAnsiChar(ChannelName)));
end;

procedure TIGCsource.Disconnect;
begin
   DLLcheckResult(IGCsourceDisconnect(FHandle));
end;

procedure TIGCsource.WaitForDisconnect;
begin
   DLLcheckResult(IGCsourceWaitForDisconnect(FHandle));
end;

function TIGCsource.WaitForDisconnectWithTimeout
(
   TimeoutInMilliseconds : Integer
) : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGCsourceWaitForDisconnectWithTimeout(FHandle, TimeoutInMilliseconds, Addr(ResultValue)));
   Result := ResultValue;
end;

function IGCsourceMessageRequestedCallback
(
   Receiver : TIGCsource;
   Inputs : TIGCsourceMessageRequestedEventInputsHandle;
   Outputs : TIGCsourceMessageRequestedEventOutputsHandle
) : TIGCresultHandle; stdcall;
begin
   if Assigned(Receiver.FOnMessageRequested) then
   begin
      Receiver.FOnMessageRequested(Receiver, IGCsourceMessageRequestedEventInputsCreateObjectWithHandle(Inputs), IGCsourceMessageRequestedEventOutputsCreateObjectWithHandle(Outputs));
   end;
   Result := nil;
end;

function IGCsourceMessageRequestCompletedCallback
(
   Receiver : TIGCsource;
   Inputs : TIGCsourceMessageRequestCompletedEventInputsHandle;
   Outputs : TIGCsourceMessageRequestCompletedEventOutputsHandle
) : TIGCresultHandle; stdcall;
begin
   if Assigned(Receiver.FOnMessageRequestCompleted) then
   begin
      Receiver.FOnMessageRequestCompleted(Receiver, IGCsourceMessageRequestCompletedEventInputsCreateObjectWithHandle(Inputs), IGCsourceMessageRequestCompletedEventOutputsCreateObjectWithHandle(Outputs));
   end;
   Result := nil;
end;

function IGCsourceDisconnectedCallback
(
   Receiver : TIGCsource
) : TIGCresultHandle; stdcall;
begin
   if Assigned(Receiver.FOnDisconnected) then
   begin
      Receiver.FOnDisconnected(Receiver);
   end;
   Result := nil;
end;

function IGCdestinationCreate
(
   ReturnValue : TIGCdestinationHandlePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationCreate@4';

function IGCdestinationAddRef
(
   Handle : TIGCdestinationHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationAddRef@4';

function IGCdestinationRelease
(
   Handle : TIGCdestinationHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationRelease@4';

function IGCdestinationAddListener
(
   Handle : TIGCdestinationHandle;
   pListener : Pointer
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationAddListener@8';

function IGCdestinationRemoveListener
(
   Handle : TIGCdestinationHandle;
   pListener : Pointer
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationRemoveListener@8';

function IGCdestinationGetDisconnectReason
(
   Handle : TIGCdestinationHandle;
   ReturnValue : TIGCdisconnectReasonHandlePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationGetDisconnectReason@8';

function IGCdestinationGetConnectTimeout
(
   Handle : TIGCdestinationHandle;
   ReturnValue : TIntegerPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationGetConnectTimeout@8';

function IGCdestinationSetConnectTimeout
(
   Handle : TIGCdestinationHandle;
   Value : Integer
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationSetConnectTimeout@8';

function IGCdestinationEnableDebugLogging
(
   Handle : TIGCdestinationHandle;
   FileName : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationEnableDebugLogging@8';

function IGCdestinationConnect
(
   Handle : TIGCdestinationHandle;
   HostName : PAnsiChar;
   PortNumber : Integer;
   ChannelName : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationConnect@16';

function IGCdestinationDisconnect
(
   Handle : TIGCdestinationHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationDisconnect@4';

function IGCdestinationWaitForDisconnect
(
   Handle : TIGCdestinationHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationWaitForDisconnect@4';

function IGCdestinationWaitForDisconnectWithTimeout
(
   Handle : TIGCdestinationHandle;
   TimeoutInMilliseconds : Integer;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGCdestinationWaitForDisconnectWithTimeout@12';

type TIGCdestinationOnMessageReceivedCallback = function
(
   Handle : TIGCdestination;
   Inputs : TIGCdestinationMessageReceivedEventInputsHandle;
   Outputs : TIGCdestinationMessageReceivedEventOutputsHandle
) : TIGCresultHandle; stdcall;

function IGCdestinationSetMessageReceivedCallback(Callback : TIGCdestinationOnMessageReceivedCallback)
: TIGCresultHandle; stdcall; external 'IGC.dll' name '_IGCdestinationSetMessageReceivedCallback@4';

type TIGCdestinationOnResubmissionPreviewMessageReceivedCallback = function
(
   Handle : TIGCdestination;
   Inputs : TIGCdestinationMessageReceivedEventInputsHandle;
   Outputs : TIGCdestinationMessageReceivedEventOutputsHandle
) : TIGCresultHandle; stdcall;

function IGCdestinationSetResubmissionPreviewMessageReceivedCallback(Callback : TIGCdestinationOnResubmissionPreviewMessageReceivedCallback)
: TIGCresultHandle; stdcall; external 'IGC.dll' name '_IGCdestinationSetResubmissionPreviewMessageReceivedCallback@4';

type TIGCdestinationOnDisconnectedCallback = function
(
   Handle : TIGCdestination
) : TIGCresultHandle; stdcall;

function IGCdestinationSetDisconnectedCallback(Callback : TIGCdestinationOnDisconnectedCallback)
: TIGCresultHandle; stdcall; external 'IGC.dll' name '_IGCdestinationSetDisconnectedCallback@4';

constructor TIGCdestination.Create(Owner: TComponent);
begin
   FHandle := nil;
   inherited Create(Owner);
   DLLcheckResult(IGCdestinationCreate(Addr(FHandle)));
   DLLcheckResult(IGCdestinationAddRef(FHandle));
   DLLcheckResult(IGCdestinationAddListener(FHandle, Self));
end;

destructor TIGCdestination.Destroy;
begin
   DLLcheckResult(IGCdestinationRemoveListener(FHandle, Self));
   DLLcheckResult(IGCdestinationRelease(FHandle));
   inherited Destroy;
end;

function TIGCdestination.GetDisconnectReason : IIGCdisconnectReason;
var
   ResultValue : TIGCdisconnectReasonHandle;
begin
   DLLcheckResult(IGCdestinationGetDisconnectReason(FHandle, Addr(ResultValue)));
   Result := IGCdisconnectReasonCreateObjectWithHandle(ResultValue);
end;

function TIGCdestination.GetConnectTimeout : Integer;
var
   ResultValue : Integer;
begin
   DLLcheckResult(IGCdestinationGetConnectTimeout(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGCdestination.SetConnectTimeout
(
   Value : Integer
);
begin
   DLLcheckResult(IGCdestinationSetConnectTimeout(FHandle, Value));
end;

procedure TIGCdestination.EnableDebugLogging
(
   FileName : AnsiString
);
begin
   DLLcheckResult(IGCdestinationEnableDebugLogging(FHandle, PAnsiChar(FileName)));
end;

procedure TIGCdestination.Connect
(
   HostName : AnsiString; PortNumber : Integer; ChannelName : AnsiString
);
begin
   DLLcheckResult(IGCdestinationConnect(FHandle, PAnsiChar(HostName), PortNumber, PAnsiChar(ChannelName)));
end;

procedure TIGCdestination.Disconnect;
begin
   DLLcheckResult(IGCdestinationDisconnect(FHandle));
end;

procedure TIGCdestination.WaitForDisconnect;
begin
   DLLcheckResult(IGCdestinationWaitForDisconnect(FHandle));
end;

function TIGCdestination.WaitForDisconnectWithTimeout
(
   TimeoutInMilliseconds : Integer
) : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGCdestinationWaitForDisconnectWithTimeout(FHandle, TimeoutInMilliseconds, Addr(ResultValue)));
   Result := ResultValue;
end;

function IGCdestinationMessageReceivedCallback
(
   Receiver : TIGCdestination;
   Inputs : TIGCdestinationMessageReceivedEventInputsHandle;
   Outputs : TIGCdestinationMessageReceivedEventOutputsHandle
) : TIGCresultHandle; stdcall;
begin
   if Assigned(Receiver.FOnMessageReceived) then
   begin
      Receiver.FOnMessageReceived(Receiver, IGCdestinationMessageReceivedEventInputsCreateObjectWithHandle(Inputs), IGCdestinationMessageReceivedEventOutputsCreateObjectWithHandle(Outputs));
   end;
   Result := nil;
end;

function IGCdestinationResubmissionPreviewMessageReceivedCallback
(
   Receiver : TIGCdestination;
   Inputs : TIGCdestinationMessageReceivedEventInputsHandle;
   Outputs : TIGCdestinationMessageReceivedEventOutputsHandle
) : TIGCresultHandle; stdcall;
begin
   if Assigned(Receiver.FOnResubmissionPreviewMessageReceived) then
   begin
      Receiver.FOnResubmissionPreviewMessageReceived(Receiver, IGCdestinationMessageReceivedEventInputsCreateObjectWithHandle(Inputs), IGCdestinationMessageReceivedEventOutputsCreateObjectWithHandle(Outputs));
   end;
   Result := nil;
end;

function IGCdestinationDisconnectedCallback
(
   Receiver : TIGCdestination
) : TIGCresultHandle; stdcall;
begin
   if Assigned(Receiver.FOnDisconnected) then
   begin
      Receiver.FOnDisconnected(Receiver);
   end;
   Result := nil;
end;

{: 
   This class is used to represent an individual Iguana log message. 
  
}
type TIGClogMessage = class(TIGCiunknown, IIGClogMessage)
   private
      FHandle : TIGClogMessageHandle;
   public
      constructor Create;
      constructor CreateWithHandle(Handle : TIGClogMessageHandle);
      function _AddRef : Integer; override; stdcall;
      function _Release : Integer; override; stdcall;
      destructor Destroy; override;
      {$IFNDEF HIDE}
      
      {: 
         Provides the name of the source channel associated with the message, or an 
        empty string if the message is not associated with a specific channel. 
        
      }
      function GetChannelName : AnsiString;
      
      {: 
         Provides the type of this message 
        (Message/Ack/Success/Warning/Error/Info/Debug) 
        
      }
      function GetMessageType : AnsiString;
      
      {: 
         Provides the full body of the message. 
        
      }
      function GetContent : AnsiString;
      
      {: 
         Provides the ID that is used to uniquely identify this message. This ID can be 
        used to query related messages. 
        
      }
      function GetMessageLogId : AnsiString;
      
      {: 
         Provides the ID of the parent of this message. It will be empty if there is no 
        parent. 
        
      }
      function GetReferenceLogId : AnsiString;
      
      {: 
         Provides a timestamp of the message with second precision. Milliseconds are 
        available via the Milliseconds property. 
        
      }
      function GetTimeStamp : TDateTime;
      
      {: 
         Provides the number of milliseconds (0-999) associated with the TimeStamp 
        property. 
        
      }
      function GetMilliseconds : Integer;
      
      {: 
         This flag is set if the message has been deleted through Iguana dashboard by an 
        administrator. 
        
      }
      function GetDeleted : Boolean;
      
      {: 
         This flag is set if this error has been marked (acknowledged) through Iguana 
        dashboard by an administrator. (Only applicable to message type Error) 
        
      }
      function GetMarkedError : Boolean;
      
      {: 
         This flag is set if this message is the original of a separate resubmitted 
        message. (Only applicable to message Type Message) 
        
      }
      function GetResubmitted : Boolean;
      
      {: 
         This flag is set if this message is a re-submission an earlier message. (Only 
        applicable to message Type Message) 
        
      }
      function GetIsResubmission : Boolean;
      {$ENDIF}
      
      {: 
         Provides the name of the source channel associated with the message, or an 
        empty string if the message is not associated with a specific channel. 
        
      }
      property ChannelName : AnsiString read GetChannelName;
      
      
      {: 
         Provides the type of this message 
        (Message/Ack/Success/Warning/Error/Info/Debug) 
        
      }
      property MessageType : AnsiString read GetMessageType;
      
      
      {: 
         Provides the full body of the message. 
        
      }
      property Content : AnsiString read GetContent;
      
      
      {: 
         Provides the ID that is used to uniquely identify this message. This ID can be 
        used to query related messages. 
        
      }
      property MessageLogId : AnsiString read GetMessageLogId;
      
      
      {: 
         Provides the ID of the parent of this message. It will be empty if there is no 
        parent. 
        
      }
      property ReferenceLogId : AnsiString read GetReferenceLogId;
      
      
      {: 
         Provides a timestamp of the message with second precision. Milliseconds are 
        available via the Milliseconds property. 
        
      }
      property TimeStamp : TDateTime read GetTimeStamp;
      
      
      {: 
         Provides the number of milliseconds (0-999) associated with the TimeStamp 
        property. 
        
      }
      property Milliseconds : Integer read GetMilliseconds;
      
      
      {: 
         This flag is set if the message has been deleted through Iguana dashboard by an 
        administrator. 
        
      }
      property Deleted : Boolean read GetDeleted;
      
      
      {: 
         This flag is set if this error has been marked (acknowledged) through Iguana 
        dashboard by an administrator. (Only applicable to message type Error) 
        
      }
      property MarkedError : Boolean read GetMarkedError;
      
      
      {: 
         This flag is set if this message is the original of a separate resubmitted 
        message. (Only applicable to message Type Message) 
        
      }
      property Resubmitted : Boolean read GetResubmitted;
      
      
      {: 
         This flag is set if this message is a re-submission an earlier message. (Only 
        applicable to message Type Message) 
        
      }
      property IsResubmission : Boolean read GetIsResubmission;
      
   end;
   
function IGClogMessageCreate
(
   ReturnValue : TIGClogMessageHandlePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogMessageCreate@4';

function IGClogMessageAddRef
(
   Handle : TIGClogMessageHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogMessageAddRef@4';

function IGClogMessageRelease
(
   Handle : TIGClogMessageHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogMessageRelease@4';

function IGClogMessageGetChannelName
(
   Handle : TIGClogMessageHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogMessageGetChannelName@8';

function IGClogMessageGetMessageType
(
   Handle : TIGClogMessageHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogMessageGetMessageType@8';

function IGClogMessageGetContent
(
   Handle : TIGClogMessageHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogMessageGetContent@8';

function IGClogMessageGetMessageLogId
(
   Handle : TIGClogMessageHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogMessageGetMessageLogId@8';

function IGClogMessageGetReferenceLogId
(
   Handle : TIGClogMessageHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogMessageGetReferenceLogId@8';

function IGClogMessageGetTimeStamp
(
   Handle : TIGClogMessageHandle;
   ReturnValue : TDoublePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogMessageGetTimeStamp@8';

function IGClogMessageGetMilliseconds
(
   Handle : TIGClogMessageHandle;
   ReturnValue : TIntegerPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogMessageGetMilliseconds@8';

function IGClogMessageGetDeleted
(
   Handle : TIGClogMessageHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogMessageGetDeleted@8';

function IGClogMessageGetMarkedError
(
   Handle : TIGClogMessageHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogMessageGetMarkedError@8';

function IGClogMessageGetResubmitted
(
   Handle : TIGClogMessageHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogMessageGetResubmitted@8';

function IGClogMessageGetIsResubmission
(
   Handle : TIGClogMessageHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogMessageGetIsResubmission@8';

constructor TIGClogMessage.Create();
begin
   inherited Create;
   FHandle := nil;
   DLLcheckResult(IGClogMessageCreate(Addr(FHandle)));
end;

constructor TIGClogMessage.CreateWithHandle(Handle : TIGClogMessageHandle);
begin
   inherited Create;
   FHandle := Handle;
end;

function TIGClogMessage._AddRef : Integer;
begin
   Result := inherited _AddRef;
   DLLcheckResult(IGClogMessageAddRef(FHandle));
end;

function TIGClogMessage._Release : Integer;
begin
   DLLcheckResult(IGClogMessageRelease(FHandle));
Result := inherited _Release;
end;

destructor TIGClogMessage.Destroy;
begin
   inherited Destroy;
end;

function IGClogMessageCreateObject : IIGClogMessage;
begin
   Result := TIGClogMessage.Create();
end;

function IGClogMessageCreateObjectWithHandle(Handle : TIGClogMessageHandle) : IIGClogMessage;
begin
   Result := TIGClogMessage.CreateWithHandle(Handle);
end;

function TIGClogMessage.GetChannelName : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGClogMessageGetChannelName(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGClogMessage.GetMessageType : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGClogMessageGetMessageType(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGClogMessage.GetContent : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGClogMessageGetContent(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGClogMessage.GetMessageLogId : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGClogMessageGetMessageLogId(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGClogMessage.GetReferenceLogId : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGClogMessageGetReferenceLogId(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGClogMessage.GetTimeStamp : TDateTime;
var
   ResultValue : Double;
begin
   DLLcheckResult(IGClogMessageGetTimeStamp(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGClogMessage.GetMilliseconds : Integer;
var
   ResultValue : Integer;
begin
   DLLcheckResult(IGClogMessageGetMilliseconds(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGClogMessage.GetDeleted : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogMessageGetDeleted(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGClogMessage.GetMarkedError : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogMessageGetMarkedError(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGClogMessage.GetResubmitted : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogMessageGetResubmitted(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGClogMessage.GetIsResubmission : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogMessageGetIsResubmission(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

{: 
   This class is used to describe the result of Execute. 
  
}
type TIGClogQueryResult = class(TIGCiunknown, IIGClogQueryResult)
   private
      FHandle : TIGClogQueryResultHandle;
   public
      constructor Create;
      constructor CreateWithHandle(Handle : TIGClogQueryResultHandle);
      function _AddRef : Integer; override; stdcall;
      function _Release : Integer; override; stdcall;
      destructor Destroy; override;
      {$IFNDEF HIDE}
      
      {: 
         Indicates that the query was executed successfully. 
        
      }
      function GetSuccess : Boolean;
      
      {: 
         Provides a textual description of the error which occured if Success is false. 
        
      }
      function GetErrorDescription : AnsiString;
      
      {: 
         Provides an array of IIGClogMessage which were returned by Iguana in response 
        to the query. 
        
      }
      function GetMessage(MessageIndex : Integer) : IIGClogMessage;
      {$ENDIF}
      
      {: 
        Returns the total number of Messages.
        
        See also the Message property.
        
      }
      function CountOfMessage : Integer;
      
      {: 
         Indicates that the query was executed successfully. 
        
      }
      property Success : Boolean read GetSuccess;
      
      
      {: 
         Provides a textual description of the error which occured if Success is false. 
        
      }
      property ErrorDescription : AnsiString read GetErrorDescription;
      
      
      {: 
         Provides an array of IIGClogMessage which were returned by Iguana in response 
        to the query. 
        
      }
      property Message[Index : Integer] : IIGClogMessage read GetMessage;
      
   end;
   
function IGClogQueryResultCreate
(
   ReturnValue : TIGClogQueryResultHandlePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryResultCreate@4';

function IGClogQueryResultAddRef
(
   Handle : TIGClogQueryResultHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryResultAddRef@4';

function IGClogQueryResultRelease
(
   Handle : TIGClogQueryResultHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryResultRelease@4';

function IGClogQueryResultGetSuccess
(
   Handle : TIGClogQueryResultHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryResultGetSuccess@8';

function IGClogQueryResultGetErrorDescription
(
   Handle : TIGClogQueryResultHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryResultGetErrorDescription@8';

function IGClogQueryResultGetMessage
(
   Handle : TIGClogQueryResultHandle;
   MessageIndex : Integer;
   ReturnValue : TIGClogMessageHandlePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryResultGetMessage@12';

function IGClogQueryResultCountOfMessage
(
   Handle : TIGClogQueryResultHandle;
   ReturnValue : TIntegerPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryResultCountOfMessage@8';

constructor TIGClogQueryResult.Create();
begin
   inherited Create;
   FHandle := nil;
   DLLcheckResult(IGClogQueryResultCreate(Addr(FHandle)));
end;

constructor TIGClogQueryResult.CreateWithHandle(Handle : TIGClogQueryResultHandle);
begin
   inherited Create;
   FHandle := Handle;
end;

function TIGClogQueryResult._AddRef : Integer;
begin
   Result := inherited _AddRef;
   DLLcheckResult(IGClogQueryResultAddRef(FHandle));
end;

function TIGClogQueryResult._Release : Integer;
begin
   DLLcheckResult(IGClogQueryResultRelease(FHandle));
Result := inherited _Release;
end;

destructor TIGClogQueryResult.Destroy;
begin
   inherited Destroy;
end;

function IGClogQueryResultCreateObject : IIGClogQueryResult;
begin
   Result := TIGClogQueryResult.Create();
end;

function IGClogQueryResultCreateObjectWithHandle(Handle : TIGClogQueryResultHandle) : IIGClogQueryResult;
begin
   Result := TIGClogQueryResult.CreateWithHandle(Handle);
end;

function TIGClogQueryResult.GetSuccess : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogQueryResultGetSuccess(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGClogQueryResult.GetErrorDescription : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGClogQueryResultGetErrorDescription(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function TIGClogQueryResult.GetMessage
(
   MessageIndex : Integer
) : IIGClogMessage;
var
   ResultValue : TIGClogMessageHandle;
begin
   DLLcheckResult(IGClogQueryResultGetMessage(FHandle, MessageIndex, Addr(ResultValue)));
   Result := IGClogMessageCreateObjectWithHandle(ResultValue);
end;

function TIGClogQueryResult.CountOfMessage : Integer;
var
   ResultValue : Integer;
begin
   DLLcheckResult(IGClogQueryResultCountOfMessage(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

function IGClogQueryCreate
(
   ReturnValue : TIGClogQueryHandlePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryCreate@4';

function IGClogQueryAddRef
(
   Handle : TIGClogQueryHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryAddRef@4';

function IGClogQueryRelease
(
   Handle : TIGClogQueryHandle
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryRelease@4';

function IGClogQueryGetHost
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetHost@8';

function IGClogQuerySetHost
(
   Handle : TIGClogQueryHandle;
   Value : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetHost@8';

function IGClogQueryGetPort
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TIntegerPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetPort@8';

function IGClogQuerySetPort
(
   Handle : TIGClogQueryHandle;
   Value : Integer
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetPort@8';

function IGClogQueryGetUsername
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetUsername@8';

function IGClogQuerySetUsername
(
   Handle : TIGClogQueryHandle;
   Value : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetUsername@8';

function IGClogQueryGetPassword
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetPassword@8';

function IGClogQuerySetPassword
(
   Handle : TIGClogQueryHandle;
   Value : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetPassword@8';

function IGClogQueryGetEncrypt
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetEncrypt@8';

function IGClogQuerySetEncrypt
(
   Handle : TIGClogQueryHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetEncrypt@8';

function IGClogQueryGetFilter
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetFilter@8';

function IGClogQuerySetFilter
(
   Handle : TIGClogQueryHandle;
   Value : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetFilter@8';

function IGClogQueryGetChannelName
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetChannelName@8';

function IGClogQuerySetChannelName
(
   Handle : TIGClogQueryHandle;
   Value : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetChannelName@8';

function IGClogQueryGetMessageLogId
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TPAnsiCharPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetMessageLogId@8';

function IGClogQuerySetMessageLogId
(
   Handle : TIGClogQueryHandle;
   Value : PAnsiChar
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetMessageLogId@8';

function IGClogQueryGetIncludeMessageMessages
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetIncludeMessageMessages@8';

function IGClogQuerySetIncludeMessageMessages
(
   Handle : TIGClogQueryHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetIncludeMessageMessages@8';

function IGClogQueryGetIncludeAckMessages
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetIncludeAckMessages@8';

function IGClogQuerySetIncludeAckMessages
(
   Handle : TIGClogQueryHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetIncludeAckMessages@8';

function IGClogQueryGetIncludeSuccessMessages
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetIncludeSuccessMessages@8';

function IGClogQuerySetIncludeSuccessMessages
(
   Handle : TIGClogQueryHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetIncludeSuccessMessages@8';

function IGClogQueryGetIncludeWarningMessages
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetIncludeWarningMessages@8';

function IGClogQuerySetIncludeWarningMessages
(
   Handle : TIGClogQueryHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetIncludeWarningMessages@8';

function IGClogQueryGetIncludeErrorMessages
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetIncludeErrorMessages@8';

function IGClogQuerySetIncludeErrorMessages
(
   Handle : TIGClogQueryHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetIncludeErrorMessages@8';

function IGClogQueryGetIncludeMarkedErrorMessages
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetIncludeMarkedErrorMessages@8';

function IGClogQuerySetIncludeMarkedErrorMessages
(
   Handle : TIGClogQueryHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetIncludeMarkedErrorMessages@8';

function IGClogQueryGetIncludeUnmarkedErrorMessages
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetIncludeUnmarkedErrorMessages@8';

function IGClogQuerySetIncludeUnmarkedErrorMessages
(
   Handle : TIGClogQueryHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetIncludeUnmarkedErrorMessages@8';

function IGClogQueryGetIncludeInfoMessages
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetIncludeInfoMessages@8';

function IGClogQuerySetIncludeInfoMessages
(
   Handle : TIGClogQueryHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetIncludeInfoMessages@8';

function IGClogQueryGetIncludeDebugMessages
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetIncludeDebugMessages@8';

function IGClogQuerySetIncludeDebugMessages
(
   Handle : TIGClogQueryHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetIncludeDebugMessages@8';

function IGClogQueryGetIncludeDeleted
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetIncludeDeleted@8';

function IGClogQuerySetIncludeDeleted
(
   Handle : TIGClogQueryHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetIncludeDeleted@8';

function IGClogQueryGetIncludeNonDeleted
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetIncludeNonDeleted@8';

function IGClogQuerySetIncludeNonDeleted
(
   Handle : TIGClogQueryHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetIncludeNonDeleted@8';

function IGClogQueryGetIncludeSourceLogs
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TBooleanPtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetIncludeSourceLogs@8';

function IGClogQuerySetIncludeSourceLogs
(
   Handle : TIGClogQueryHandle;
   Value : Boolean
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetIncludeSourceLogs@8';

function IGClogQueryGetAfter
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TDoublePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetAfter@8';

function IGClogQuerySetAfter
(
   Handle : TIGClogQueryHandle;
   Value : Double
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetAfter@12';

function IGClogQueryGetBefore
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TDoublePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryGetBefore@8';

function IGClogQuerySetBefore
(
   Handle : TIGClogQueryHandle;
   Value : Double
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQuerySetBefore@12';

function IGClogQueryExecute
(
   Handle : TIGClogQueryHandle;
   ReturnValue : TIGClogQueryResultHandlePtr
) : TIGCresultHandle; stdcall; 
external 'IGC.dll' name '_IGClogQueryExecute@8';

constructor TIGClogQuery.Create(Owner: TComponent);
begin
   FHandle := nil;
   inherited Create(Owner);
   DLLcheckResult(IGClogQueryCreate(Addr(FHandle)));
   DLLcheckResult(IGClogQueryAddRef(FHandle));
end;

destructor TIGClogQuery.Destroy;
begin
   DLLcheckResult(IGClogQueryRelease(FHandle));
   inherited Destroy;
end;

function TIGClogQuery.GetHost : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGClogQueryGetHost(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetHost
(
   Value : AnsiString
);
begin
   DLLcheckResult(IGClogQuerySetHost(FHandle, PAnsiChar(Value)));
end;

function TIGClogQuery.GetPort : Integer;
var
   ResultValue : Integer;
begin
   DLLcheckResult(IGClogQueryGetPort(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetPort
(
   Value : Integer
);
begin
   DLLcheckResult(IGClogQuerySetPort(FHandle, Value));
end;

function TIGClogQuery.GetUsername : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGClogQueryGetUsername(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetUsername
(
   Value : AnsiString
);
begin
   DLLcheckResult(IGClogQuerySetUsername(FHandle, PAnsiChar(Value)));
end;

function TIGClogQuery.GetPassword : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGClogQueryGetPassword(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetPassword
(
   Value : AnsiString
);
begin
   DLLcheckResult(IGClogQuerySetPassword(FHandle, PAnsiChar(Value)));
end;

function TIGClogQuery.GetEncrypt : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogQueryGetEncrypt(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetEncrypt
(
   Value : Boolean
);
begin
   DLLcheckResult(IGClogQuerySetEncrypt(FHandle, Value));
end;

function TIGClogQuery.GetFilter : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGClogQueryGetFilter(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetFilter
(
   Value : AnsiString
);
begin
   DLLcheckResult(IGClogQuerySetFilter(FHandle, PAnsiChar(Value)));
end;

function TIGClogQuery.GetChannelName : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGClogQueryGetChannelName(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetChannelName
(
   Value : AnsiString
);
begin
   DLLcheckResult(IGClogQuerySetChannelName(FHandle, PAnsiChar(Value)));
end;

function TIGClogQuery.GetMessageLogId : AnsiString;
var
   ResultValue : PAnsiChar;
begin
   DLLcheckResult(IGClogQueryGetMessageLogId(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetMessageLogId
(
   Value : AnsiString
);
begin
   DLLcheckResult(IGClogQuerySetMessageLogId(FHandle, PAnsiChar(Value)));
end;

function TIGClogQuery.GetIncludeMessageMessages : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogQueryGetIncludeMessageMessages(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetIncludeMessageMessages
(
   Value : Boolean
);
begin
   DLLcheckResult(IGClogQuerySetIncludeMessageMessages(FHandle, Value));
end;

function TIGClogQuery.GetIncludeAckMessages : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogQueryGetIncludeAckMessages(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetIncludeAckMessages
(
   Value : Boolean
);
begin
   DLLcheckResult(IGClogQuerySetIncludeAckMessages(FHandle, Value));
end;

function TIGClogQuery.GetIncludeSuccessMessages : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogQueryGetIncludeSuccessMessages(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetIncludeSuccessMessages
(
   Value : Boolean
);
begin
   DLLcheckResult(IGClogQuerySetIncludeSuccessMessages(FHandle, Value));
end;

function TIGClogQuery.GetIncludeWarningMessages : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogQueryGetIncludeWarningMessages(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetIncludeWarningMessages
(
   Value : Boolean
);
begin
   DLLcheckResult(IGClogQuerySetIncludeWarningMessages(FHandle, Value));
end;

function TIGClogQuery.GetIncludeErrorMessages : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogQueryGetIncludeErrorMessages(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetIncludeErrorMessages
(
   Value : Boolean
);
begin
   DLLcheckResult(IGClogQuerySetIncludeErrorMessages(FHandle, Value));
end;

function TIGClogQuery.GetIncludeMarkedErrorMessages : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogQueryGetIncludeMarkedErrorMessages(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetIncludeMarkedErrorMessages
(
   Value : Boolean
);
begin
   DLLcheckResult(IGClogQuerySetIncludeMarkedErrorMessages(FHandle, Value));
end;

function TIGClogQuery.GetIncludeUnmarkedErrorMessages : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogQueryGetIncludeUnmarkedErrorMessages(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetIncludeUnmarkedErrorMessages
(
   Value : Boolean
);
begin
   DLLcheckResult(IGClogQuerySetIncludeUnmarkedErrorMessages(FHandle, Value));
end;

function TIGClogQuery.GetIncludeInfoMessages : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogQueryGetIncludeInfoMessages(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetIncludeInfoMessages
(
   Value : Boolean
);
begin
   DLLcheckResult(IGClogQuerySetIncludeInfoMessages(FHandle, Value));
end;

function TIGClogQuery.GetIncludeDebugMessages : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogQueryGetIncludeDebugMessages(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetIncludeDebugMessages
(
   Value : Boolean
);
begin
   DLLcheckResult(IGClogQuerySetIncludeDebugMessages(FHandle, Value));
end;

function TIGClogQuery.GetIncludeDeleted : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogQueryGetIncludeDeleted(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetIncludeDeleted
(
   Value : Boolean
);
begin
   DLLcheckResult(IGClogQuerySetIncludeDeleted(FHandle, Value));
end;

function TIGClogQuery.GetIncludeNonDeleted : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogQueryGetIncludeNonDeleted(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetIncludeNonDeleted
(
   Value : Boolean
);
begin
   DLLcheckResult(IGClogQuerySetIncludeNonDeleted(FHandle, Value));
end;

function TIGClogQuery.GetIncludeSourceLogs : Boolean;
var
   ResultValue : Boolean;
begin
   DLLcheckResult(IGClogQueryGetIncludeSourceLogs(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetIncludeSourceLogs
(
   Value : Boolean
);
begin
   DLLcheckResult(IGClogQuerySetIncludeSourceLogs(FHandle, Value));
end;

function TIGClogQuery.GetAfter : TDateTime;
var
   ResultValue : Double;
begin
   DLLcheckResult(IGClogQueryGetAfter(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetAfter
(
   Value : TDateTime
);
begin
   DLLcheckResult(IGClogQuerySetAfter(FHandle, Value));
end;

function TIGClogQuery.GetBefore : TDateTime;
var
   ResultValue : Double;
begin
   DLLcheckResult(IGClogQueryGetBefore(FHandle, Addr(ResultValue)));
   Result := ResultValue;
end;

procedure TIGClogQuery.SetBefore
(
   Value : TDateTime
);
begin
   DLLcheckResult(IGClogQuerySetBefore(FHandle, Value));
end;

function TIGClogQuery.Execute : IIGClogQueryResult;
var
   ResultValue : TIGClogQueryResultHandle;
begin
   DLLcheckResult(IGClogQueryExecute(FHandle, Addr(ResultValue)));
   Result := IGClogQueryResultCreateObjectWithHandle(ResultValue);
end;

initialization
   
   IGCsourceSetMessageRequestedCallback(IGCsourceMessageRequestedCallback);
   IGCsourceSetMessageRequestCompletedCallback(IGCsourceMessageRequestCompletedCallback);
   IGCsourceSetDisconnectedCallback(IGCsourceDisconnectedCallback);
   
   IGCdestinationSetMessageReceivedCallback(IGCdestinationMessageReceivedCallback);
   IGCdestinationSetResubmissionPreviewMessageReceivedCallback(IGCdestinationResubmissionPreviewMessageReceivedCallback);
   IGCdestinationSetDisconnectedCallback(IGCdestinationDisconnectedCallback);
   
end.
