unit ClientFrm;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, CHM, PrefixTest, ScktComp, CHMnet;

type
  TClientForm = class(TForm)
    hl7Engine: TPrefixTestEngine;
    pnlControls: TPanel;
    pnlDisplay: TPanel;
    memOutput: TMemo;
    cbMessage: TComboBox;
    btnSend: TButton;
    btnToggleConnection: TButton;
    lblPortNumber: TLabel;
    lblHost: TLabel;
    edtPortNumber: TEdit;
    edtHostName: TEdit;
    llpClient: TCHMllpClient;
    lblConfiguration: TLabel;
    cbConfiguration: TComboBox;
    lblMessage: TLabel;
    procedure btnSendClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure hl7EngineLog(Sender: TObject; Line: String);
    procedure llpClientClosed(Sender: TObject);
    procedure llpClientConnected(Sender: TObject);
    procedure llpClientDataIgnored(Sender: TObject; Data: String);
    procedure llpClientErrorReceived(Sender: TObject; Description: String;
      Code: Integer);
    procedure llpClientMessageReceived(Sender: TObject; Message: String);
    procedure btnToggleConnectionClick(Sender: TObject);
    procedure cbConfigurationChange(Sender: TObject);
  private
    // Begin generation declarations (comment used as an anchor by STD)
    function GenerateADTA04 : string;
    // End generation declarations (comment used as an anchor by STD)

    { Private declarations }
  public
    { Public declarations }
  end;

var
  ClientForm: TClientForm;

implementation

{$R *.DFM}

// This application is a simple example of using the Chameleon generated objects in a 'Client'
// configuration.  It is intended to be a helpful starting point in understanding how to use these objects
// but must be fleshed out in the following areas to provide a full solution for an
// application HL7 interface:
// 1) You will need to work out how your application will handle the logging of messages
//    and data, in particular how bad transactions should be logged for effective troubleshooting.
// 2) The code will need to be modified to insert the parsed data into a database whether
//    by using explicit database calls or going through some type of middle tier layer that
//    your application may support.
// 3) Some customers choose to deploy HL7 interfaces as Windows Services.  This can be done
//    easily with the Chameleon objects.  One thing to keep in mind though is that the networking components
//    supplied with Chameleon require a Windows 'message loop'.  Often times Windows Services do
//    not have a message loop - but one can be easily set up by invoking RunMessageLoop on
//    the networking component supplied with Chameleon.  See the manual for running Chameleon
//    within services.
// 4) Definitely take the time to read the manual and go through the tutorials after looking
//    at this example before attempting to deploy a production solution.  We do provide custom
//    onsite training and technical implementation services if you require them.
//
// If you are looking for a much more complete 'out of the box' solution for your HL7 needs it would be
// a good idea to evaluate Iguana - Iguana is powered by Chameleon but
// provides a complete runtime web based infrastructure for your HL7 interfaces.
// So it provides advanced logging and monitoring capability for you
// which makes it a very attractive option for many customers.

procedure TClientForm.FormCreate(Sender: TObject);
var
   ConfigIndex : Integer;
begin
   // Setting up the combo box is just part of mechanics of this example which
   // is for teaching purposes only.  A real HL7 client would most likely be part
   // of a backend service.
   // Begin combo box initialization (comment used as an anchor by STD)
   cbMessage.Items.Add('ADTA04');
   // End combo box initialization (comment used as an anchor by STD)

   cbMessage.ItemIndex := 0;

   // We load up the message definition file or 'vmd' file during the initialization
   // of the Form.
   hl7Engine.Load(ExtractFilePath(Application.ExeName) + 'test_data.vmd');

   for ConfigIndex := 0 to hl7Engine.CountOfConfig-1 do
   begin
      cbConfiguration.Items.Add(hl7Engine.GetConfigName(ConfigIndex));
   end;
   cbConfiguration.ItemIndex := hl7Engine.CurrentConfigIndex;

   cbMessage.Text := cbMessage.Items.Strings[0];
end;

procedure TClientForm.hl7EngineLog(Sender: TObject; Line: String);
begin
   // This method is called everytime we invoke the 'WriteToLog' method on the engine object.  This
   // code is only for demonstration purposes.  Memo controls can only take a certain amount
   // of data - 32k at the time this example was written.  As a result we check the length of
   // the memo control and truncate it if it reaches this limit.

   // It should be strongly emphasized that this solution is only for demonstration purposes.
   // A real HL7 interface should have some type of log file system.  Iguana for
   // instance has a very nice logging system that allows administrators to drill into and browse
   // processed messages and errors.  How you implement this logging is up to your requirements
   // for run time management of your HL7 interface.
   memOutput.Lines.BeginUpdate;

   if (Length(memOutput.Text) > 30000) then
   begin
      memOutput.Text := Line;
      memOutput.Lines.EndUpdate;
   end
   else
   begin
      memOutput.Lines.EndUpdate;
      memOutput.Lines.Add(Line);
   end;
end;

procedure TClientForm.btnSendClick(Sender: TObject);
var
   MessageData : string;
begin
   // Begin combo selection checking (comment used as an anchor by STD)
   if cbMessage.Text = 'ADTA04' then
   begin
      MessageData := GenerateADTA04;
   end;
   // End combo selection checking (comment used as an anchor by STD)



   hl7Engine.WriteToLog('Generated ' + cbMessage.Text + #13#10);
   hl7Engine.WriteToLog(llpClient.MakeMessagePrintable(MessageData, #13#10, -1));

   if (llpClient.IsConnected) then
   begin
      llpClient.TransmitMessage(MessageData);
   end
   else
   begin
      hl7Engine.WriteToLog('The Client must be connected before sending any data.');
   end;
end;

// These generated methods are examples of how an HL7 message
// can be created using Chameleon's generated stubcode objects.
// We are populating these objects with dummy data.  In a real
// application you would need to obtain this data from somewhere
// like a database.
//
// It should be noted that each Msg object corresponds to a
// message defined in the vmd file loaded into the hl7Engine.
// These objects have tables and sub tables with properties that you
// can use to populate the message.
//
// It must be emphasized that this will be a mirror of the 'table grammar' for
// each message - i.e. the user defined definitions of each table and the fields
// in those tables as defined in the Chameleon GUI.
//
// Also keep in mind that this is using the static stubcode interface of Chameleon.
// For advanced applications it is possible to use a dynamic interface to populate
// messages.  See the manual for more details.
// Begin generation functions (comment used as an anchor by STD)
function TClientForm.GenerateADTA04 : string;
var
    Msg : TPrefixTestmsgADTA04;
begin
    Msg := TPrefixTestmsgADTA04.Create(hl7Engine);
    try
        Msg.InfoTbl.AddRow;
        Msg.InfoTbl[0].SetIDPid := 108;
        Msg.InfoTbl[0].PatientNameFamilyNameSurnamerepeatsonlyfirstinstancemapped := 'PatientNameFamilyNameSurnamerepeatsonlyfirstinstancemapped Dummy Value';
        Msg.InfoTbl[0].PatientNameGivenNamerepeatsonlyfirstinstancemapped := 'PatientNameGivenNamerepeatsonlyfirstinstancemapped Dummy Value';
        Msg.InfoTbl[0].DatetimeOfBirthTime.DateTime := Now;
        Msg.InfoTbl[0].AdministrativeSex := 'AdministrativeSex Dummy Value';
        Result := Msg.GenerateFlatWire;
    finally
        Msg.Free
    end;
end;
// End generation functions (comment used as an anchor by STD)


// The Connected event is very important.  One common mistake
// that developers often make that are new to socket programming
// is to try and invoke the Connect method and then immediately
// send data via the socket.  This is not possible to do until the
// socket is actually connected.
procedure TClientForm.llpClientConnected(Sender: TObject);
begin
   hl7Engine.WriteToLog('Connected to peer.');
   btnToggleConnection.Caption := '&Disconnect';
   btnSend.Enabled := true;
end;

// This event is triggered when the llpClient socket receives
// an LLP wrapped HL7 message.  The envelope header and trailer
// characters will have been stripped from the Message
// before being passed to your application in this event.
//
// Most of the time the message received is an ACK message.  However
// if you are implementing a lab query interface it might be a lab result
// message.  For this example we are assuming it is an ACK message and
// just printing it to the memo control.
procedure TClientForm.llpClientMessageReceived(Sender: TObject;
  Message: String);
begin
   // The MakeMessagePrintable call is used to transform \r --> \r\n so that
   // the HL7 message is displayed nicely in within the memo control.  Having
   // the third argument set to -1 means we are not truncating the output while
   // #13#10 refers to the ascii character sequence \r (carriage return) and
   // \n (line feed).  This is just a convention for how Windows linefeeds are
   // represented.
   hl7Engine.WriteToLog('Received response.');
   hl7Engine.WriteToLog(llpClient.MakeMessagePrintable(Message, #13#10, -1));
end;

// This event is fired when a TCP/IP diconnection completes.
procedure TClientForm.llpClientClosed(Sender: TObject);
begin
   btnToggleConnection.Caption := '&Connect';
   btnSend.Enabled := false;
   hl7Engine.WriteToLog('Connection closed.');
end;

// This event is fired when we receive a TCP/IP error on the
// connection.  This will always terminate the connection so your
// real application will need logic to handle this event and determine
// if and when attempt to re-connect to the other host.
//
// One of the advantages of using Iguana instead of Chameleon is that
// Iguana will handle this for you.
procedure TClientForm.llpClientErrorReceived(Sender: TObject;
  Description: String; Code: Integer);
begin
   hl7Engine.WriteToLog('Error: ' + Description);
end;

// This event is generated when data which is not within the LLP header and trailer
// characters is received.  This should be a very rare event and usually indicates
// a problem with the implementation of the peer host that is sending HL7 back to your
// client.
procedure TClientForm.llpClientDataIgnored(Sender: TObject; Data: String);
begin
   hl7Engine.WriteToLog('Warning.  Data has been received that was not with the LLP wrapper characters');
   hl7Engine.WriteToLog(Data);
end;

// This code is just part of the mechanics of this example.
procedure TClientForm.btnToggleConnectionClick(Sender: TObject);
begin
   if (llpClient.IsConnected) then
   begin
      llpClient.Disconnect;
   end
   else
   begin
      llpClient.Connect(edtHostName.Text, StrToInt(edtPortNumber.Text));
   end;
end;

procedure TClientForm.cbConfigurationChange(Sender: TObject);
begin
   hl7Engine.CurrentConfigIndex := cbConfiguration.ItemIndex;
end;

end.
